' /////////////////////////////////////////////////////////////////////////////
' TITLE: PACMAN_TILE_DEMO_001.SPIN
'
' DESCRIPTION: Tile engine demo of making a pacman like game field with 3
' different playfield variations.
'
' VERSION: x.x
' AUTHOR: Andre' LaMothe
' LAST MODIFIED:
' COMMENTS:
'
' CONTROLS: Uses gamepad, <SELECT> to cycle between tile pages.
'
'//////////////////////////////////////////////////////////////////////////////

'//////////////////////////////////////////////////////////////////////////////
' CONSTANTS SECTION ///////////////////////////////////////////////////////////
'//////////////////////////////////////////////////////////////////////////////

CON

  _clkmode = xtal1 + pll16x       ' enable external clock range 5-10MHz and pll times 8
  _xinfreq = 5_000_000           ' set frequency to 10 MHZ plus some error due to XTAL (1000-5000 usually works)
  _stack   = 128                 ' accomodate display memory and stack

  ' button ids/bit masks
  ' NES bit encodings general for state bits
  NES_RIGHT  = %00000001
  NES_LEFT   = %00000010
  NES_DOWN   = %00000100
  NES_UP     = %00001000
  NES_START  = %00010000
  NES_SELECT = %00100000
  NES_B      = %01000000
  NES_A      = %10000000

  ' NES bit encodings for NES gamepad 0
  NES0_RIGHT  = %00000000_00000001
  NES0_LEFT   = %00000000_00000010
  NES0_DOWN   = %00000000_00000100
  NES0_UP     = %00000000_00001000
  NES0_START  = %00000000_00010000
  NES0_SELECT = %00000000_00100000
  NES0_B      = %00000000_01000000
  NES0_A      = %00000000_10000000

  ' NES bit encodings for NES gamepad 1
  NES1_RIGHT  = %00000001_00000000
  NES1_LEFT   = %00000010_00000000
  NES1_DOWN   = %00000100_00000000
  NES1_UP     = %00001000_00000000
  NES1_START  = %00010000_00000000
  NES1_SELECT = %00100000_00000000
  NES1_B      = %01000000_00000000
  NES1_A      = %10000000_00000000

  ' color constant's to make setting colors for parallax graphics setup easier
  COL_Black       = %0000_0010
  COL_DarkGrey    = %0000_0011
  COL_Grey        = %0000_0100
  COL_LightGrey   = %0000_0101
  COL_BrightGrey  = %0000_0110
  COL_White       = %0000_0111 

  ' colors are in reverse order from parallax drivers, or in order 0-360 phase lag from 0 = Blue, on NTSC color wheel
  ' so code $0 = 0 degrees, $F = 360 degrees, more intuitive mapping, and is 1:1 with actual hardware
  COL_PowerBlue   = %1111_1_100 
  COL_Blue        = %1110_1_100
  COL_SkyBlue     = %1101_1_100
  COL_AquaMarine  = %1100_1_100
  COL_LightGreen  = %1011_1_100
  COL_Green       = %1010_1_100
  COL_GreenYellow = %1001_1_100
  COL_Yellow      = %1000_1_100
  COL_Gold        = %0111_1_100
  COL_Orange      = %0110_1_100
  COL_Red         = %0101_1_100
  COL_VioletRed   = %0100_1_100
  COL_Pink        = %0011_1_100
  COL_Magenta     = %0010_1_100
  COL_Violet      = %0001_1_100
  COL_Purple      = %0000_1_100

'//////////////////////////////////////////////////////////////////////////////
' VARS SECTION ////////////////////////////////////////////////////////////////
'//////////////////////////////////////////////////////////////////////////////

VAR

' begin parameter list ////////////////////////////////////////////////////////
' tile engine data structure pointers (can be changed in real-time by app!)
long tile_map_base_ptr_parm       ' base address of the tile map
long tile_bitmaps_base_ptr_parm   ' base address of the tile bitmaps
long tile_palettes_base_ptr_parm  ' base address of the palettes

long tile_map_sprite_cntrl_parm   ' pointer to the value that holds various "control" values for the tile map/sprite engine
                                  ' currently, encodes width of map, and number of sprites to process up to 8 in following format
                                  ' $xx_xx_ss_ww, xx is don't care/unused
                                  ' ss = number of sprites to process 1..8
                                  ' ww = the number of "screens" or multiples of 16 that the tile map is
                                  ' eg. 0 would be 16 wide (standard), 1 would be 32 tiles, 2 would be 64 tiles, etc.
                                  ' this allows multiscreen width playfields and thus large horizontal/vertical scrolling games
                                  ' note that the final size is always a power of 2 multiple of 16

long tile_sprite_tbl_base_ptr_parm ' base address of sprite table


' real-time engine status variables, these are updated in real time by the
' tile engine itself, so they can be monitored outside in SPIN/ASM by game
long tile_status_bits_parm      ' vsync, hsync, etc.

' format of tile_status_bits_parm, only the Vsync status bit is updated
'
' byte 3 (unused)|byte 2 (line)|   byte 1 (tile postion)    |                     byte 0 (sync and region)      |
'|x x x x x x x x| line 8-bits | row 4 bits | column 4-bits |x x x x | region 2-bits | hsync 1-bit | vsync 1-bit|
'   b31..b24         b23..b16      b15..b12     b11..b8                    b3..b2          b1            b0
' Region 0=Top Overscan, 1=Active Video, 2=Bottom Overscan, 3=Vsync
' NOTE: In this version of the tile engine only VSYNC and REGION are valid 

' end parameter list ///////////////////////////////////////////////////////////

byte sbuffer[80]      ' string buffer for printing
long x,y, index, dir, tile_map_index  ' demo working vars

'//////////////////////////////////////////////////////////////////////////////
'OBJS SECTION /////////////////////////////////////////////////////////////////
'//////////////////////////////////////////////////////////////////////////////

OBJ


gfx:            "HEL_GFX_ENGINE_040.SPIN"

'//////////////////////////////////////////////////////////////////////////////
'PUBS SECTION /////////////////////////////////////////////////////////////////
'//////////////////////////////////////////////////////////////////////////////

' COG INTERPRETER STARTS HERE...@ THE FIRST PUB

PUB Start
' This is the first entry point the system will see when the PChip starts,
' execution ALWAYS starts on the first PUB in the source code for
' the top level file

' star the game pad driver


' initialize all vars
tile_map_index := 0

' set up tile and sprite engine data before starting it, so no ugly startup
' points ptrs to actual memory storage for tile engine
tile_map_base_ptr_parm        := @tile_map0
tile_bitmaps_base_ptr_parm    := @tile_bitmaps
tile_palettes_base_ptr_parm   := @palette_map

' these control the sprite engine, all 0 for now, no sprites
tile_map_sprite_cntrl_parm    := $00_00 ' 0 sprites, tile map set to 0=16 tiles wide, 1=32 tiles, 2=64 tiles, etc.
tile_sprite_tbl_base_ptr_parm := 0 
tile_status_bits_parm         := 0

' launch a COG with ASM video driver
gfx.start(@tile_map_base_ptr_parm)

' enter main event loop...

repeat while 1
  ' main even loop code here...

    repeat 5
      repeat 6 'show pulsed flashing catastrophic alarm
        tile_map_base_ptr_parm := @tile_map0  'basic tilemap
        waitcnt(clkfreq / 12 + cnt)           'wait 1/12 sec then show the alarm map
        tile_map_base_ptr_parm := @tile_map1  'alarm tilemap
        waitcnt(clkfreq / 10 + cnt)           'display the alarm tilemap for 1/10 sec
      tile_map_base_ptr_parm := @tile_map0    'display basic map for one second before pulsing again
      waitcnt(clkfreq/2 + cnt)
    repeat 5
      repeat 6 'show pulsed flashing alarm
        tile_map_base_ptr_parm := @tile_map0  'basic tilemap
        waitcnt(clkfreq / 12 + cnt)           'wait 1/12 sec then show the alarm map
        tile_map_base_ptr_parm := @tile_map2  'alarm tilemap
        waitcnt(clkfreq / 10 + cnt)           'display the alarm tilemap for 1/10 sec
      tile_map_base_ptr_parm := @tile_map0    'display basic map for one second before pulsing again
      waitcnt(clkfreq/2 + cnt)
    repeat 5
      repeat 6 'show pulsed flashing catastrophic alarm
        tile_map_base_ptr_parm := @tile_map0  'basic tilemap
        waitcnt(clkfreq / 12 + cnt)           'wait 1/12 sec then show the alarm map
        tile_map_base_ptr_parm := @tile_map3  'alarm tilemap
        waitcnt(clkfreq / 10 + cnt)           'display the alarm tilemap for 1/10 sec
      tile_map_base_ptr_parm := @tile_map0    'display basic map for one second before pulsing again
      waitcnt(clkfreq/2 + cnt)
    repeat 5
      repeat 6 'show pulsed flashing alarm
        tile_map_base_ptr_parm := @tile_map0  'basic tilemap
        waitcnt(clkfreq / 12 + cnt)           'wait 1/12 sec then show the alarm map
        tile_map_base_ptr_parm := @tile_map4  'alarm tilemap
        waitcnt(clkfreq / 10 + cnt)           'display the alarm tilemap for 1/10 sec
      tile_map_base_ptr_parm := @tile_map0    'display basic map for one second before pulsing again
      waitcnt(clkfreq/2 + cnt)
    repeat 5
      repeat 6 'show pulsed flashing catastrophic alarm
        tile_map_base_ptr_parm := @tile_map0  'basic tilemap
        waitcnt(clkfreq / 12 + cnt)           'wait 1/12 sec then show the alarm map
        tile_map_base_ptr_parm := @tile_map5  'alarm tilemap
        waitcnt(clkfreq / 10 + cnt)           'display the alarm tilemap for 1/10 sec
      tile_map_base_ptr_parm := @tile_map0    'display basic map for one second before pulsing again
      waitcnt(clkfreq/2 + cnt)
    repeat 5
      repeat 6 'show pulsed flashing alarm
        tile_map_base_ptr_parm := @tile_map0  'basic tilemap
        waitcnt(clkfreq / 12 + cnt)           'wait 1/12 sec then show the alarm map
        tile_map_base_ptr_parm := @tile_map6  'alarm tilemap
        waitcnt(clkfreq / 10 + cnt)           'display the alarm tilemap for 1/10 sec
      tile_map_base_ptr_parm := @tile_map0    'display basic map for one second before pulsing again
      waitcnt(clkfreq/2 + cnt)
    repeat 5
      repeat 6 'show pulsed flashing catastrophic alarm
        tile_map_base_ptr_parm := @tile_map0  'basic tilemap
        waitcnt(clkfreq / 12 + cnt)           'wait 1/12 sec then show the alarm map
        tile_map_base_ptr_parm := @tile_map7  'alarm tilemap
        waitcnt(clkfreq / 10 + cnt)           'display the alarm tilemap for 1/10 sec
      tile_map_base_ptr_parm := @tile_map0    'display basic map for one second before pulsing again
      waitcnt(clkfreq/2 + cnt)
    repeat 5
      repeat 6 'show pulsed flashing alarm
        tile_map_base_ptr_parm := @tile_map0  'basic tilemap
        waitcnt(clkfreq / 12 + cnt)           'wait 1/12 sec then show the alarm map
        tile_map_base_ptr_parm := @tile_map1  'alarm tilemap
        waitcnt(clkfreq / 10 + cnt)           'display the alarm tilemap for 1/10 sec
      tile_map_base_ptr_parm := @tile_map0    'display basic map for one second before pulsing again
      waitcnt(clkfreq/2 + cnt)
    
    ' wait a moment...
    repeat 100_000
    
  ' return back to repeat main event loop...

' parent COG will terminate now...if it gets to this point


'//////////////////////////////////////////////////////////////////////////////
'DAT SECTION //////////////////////////////////////////////////////////////////
'//////////////////////////////////////////////////////////////////////////////


DAT

tile_maps     ' you place all your 16x12 tile maps here, you can have as many as you like, in real-time simply re-point the
              ' tile_map_base_ptr_parm to any time map and within 1 frame the tile map will update
              ' the engine only renders 10x12 of the tiles on the physical screen, the other 6 columns allow you some "scroll room"

              ' 16x12 WORDS each, (0..191 WORDs, 384 bytes per tile map) 2-BYTE tiles (msb)[palette_index | tile_index](lsb)
              ' 16x12 tile map, each tile is 2 bytes, there are a total of 64 tiles possible, and thus 64 palettes
              '
              ' <---------------------------visible on screen-------------------------------->|<------ to right of screen ---------->|              
              ' column     0      1      2      3      4      5      6      7      8      9   | 10     11     12     13     14     15
'Tilemap for basic display /everything ok run
tile_map0 WORD                                                                                                                                     
              WORD      $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53 ' Row 0 
              WORD      $40_40, $00_00, $01_01, $02_02, $02_02, $02_02, $02_02, $03_03, $00_00, $20_20, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53 ' Row 1 
              WORD      $30_30, $53_53, $53_53, $13_13, $11_11, $12_12, $06_06, $53_53, $53_53, $30_30, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53 ' Row 2 
              WORD      $30_30, $53_53, $53_53, $53_53, $21_21, $22_22, $53_53, $53_53, $53_53, $30_30, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53 ' Row 3 
              WORD      $30_30, $53_53, $53_53, $53_53, $04_04, $05_05, $53_53, $53_53, $53_53, $30_30, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53 ' Row 4 
              WORD      $30_30, $53_53, $53_53, $53_53, $04_04, $05_05, $53_53, $53_53, $53_53, $30_30, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53 ' Row 5 
              WORD      $10_10, $17_17, $18_18, $31_31, $32_32, $33_33, $34_34, $25_25, $26_26, $45_45, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53 ' Row 6 
              WORD      $53_53, $27_27, $28_28, $41_41, $42_42, $43_43, $44_44, $35_35, $36_36, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53 ' Row 7 
              WORD      $53_53, $07_07, $05_05, $14_14, $23_23, $24_24, $14_14, $04_04, $08_08, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53 ' Row 8
              WORD      $53_53, $15_15, $05_05, $14_14, $06_06, $13_13, $14_14, $04_04, $16_16, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53 ' Row 9 
              WORD      $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53 ' Row 10
              WORD      $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53 ' Row 11

'Tilemap for catastrophic alarm!
tile_map1 WORD                                                                                                                                       
              WORD      $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53 ' Row 0  
              WORD      $2d_2d, $37_37, $38_38, $49_49, $49_49, $49_49, $49_49, $4a_4a, $37_37, $6f_6f, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53 ' Row 1  
              WORD      $1d_1d, $53_53, $53_53, $54_54, $1e_1e, $1f_1f, $0f_0f, $53_53, $53_53, $1d_1d, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53 ' Row 2  
              WORD      $1d_1d, $53_53, $53_53, $53_53, $2e_2e, $2f_2f, $53_53, $53_53, $53_53, $1d_1d, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53 ' Row 3  
              WORD      $1d_1d, $53_53, $53_53, $53_53, $4b_4b, $4c_4c, $53_53, $53_53, $53_53, $1d_1d, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53 ' Row 4  
              WORD      $1d_1d, $53_53, $53_53, $53_53, $4b_4b, $4c_4c, $53_53, $53_53, $53_53, $1d_1d, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53 ' Row 5  
              WORD      $46_46, $2b_2b, $2c_2c, $09_09, $0a_0a, $0b_0b, $0c_0c, $29_29, $2a_2a, $48_48, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53 ' Row 6  
              WORD      $53_53, $3b_3b, $3c_3c, $19_19, $1a_1a, $1b_1b, $1c_1c, $39_39, $3a_3a, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53 ' Row 7  
              WORD      $53_53, $50_50, $4c_4c, $55_55, $56_56, $47_47, $55_55, $4b_4b, $0e_0e, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53 ' Row 8  
              WORD      $53_53, $4f_4f, $4c_4c, $55_55, $0f_0f, $54_54, $55_55, $4b_4b, $3d_3d, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53 ' Row 9  
              WORD      $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53 ' Row 10 
              WORD      $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53 ' Row 11              

'Tilemap for turbo failure
tile_map2 WORD                                                                                                                                       
              WORD      $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53 ' Row 0  
              WORD      $40_40, $00_00, $01_01, $02_02, $02_02, $02_02, $02_02, $03_03, $00_00, $20_20, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53 ' Row 1  
              WORD      $30_30, $53_53, $53_53, $13_13, $11_11, $12_12, $06_06, $53_53, $53_53, $30_30, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53 ' Row 2  
              WORD      $30_30, $53_53, $53_53, $53_53, $21_21, $22_22, $53_53, $53_53, $53_53, $30_30, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53 ' Row 3  
              WORD      $30_30, $53_53, $53_53, $53_53, $04_04, $05_05, $53_53, $53_53, $53_53, $30_30, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53 ' Row 4  
              WORD      $30_30, $53_53, $53_53, $53_53, $04_04, $05_05, $53_53, $53_53, $53_53, $30_30, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53 ' Row 5  
              WORD      $10_10, $2b_2b, $2c_2c, $31_31, $32_32, $33_33, $34_34, $29_29, $2a_2a, $45_45, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53 ' Row 6  
              WORD      $53_53, $3b_3b, $3c_3c, $41_41, $42_42, $43_43, $44_44, $39_39, $3a_3a, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53 ' Row 7  
              WORD      $53_53, $07_07, $05_05, $14_14, $23_23, $24_24, $14_14, $04_04, $08_08, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53 ' Row 8  
              WORD      $53_53, $15_15, $05_05, $14_14, $06_06, $13_13, $14_14, $04_04, $16_16, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53 ' Row 9  
              WORD      $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53 ' Row 10 
              WORD      $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53 ' Row 11 

'Tilemap for intake failure/fuel problem (intake only)    
tile_map3 WORD                                                                                                                                      
              WORD      $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53 ' Row 0 
              WORD      $40_40, $00_00, $01_01, $02_02, $02_02, $02_02, $02_02, $03_03, $00_00, $20_20, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53 ' Row 1 
              WORD      $30_30, $53_53, $53_53, $13_13, $11_11, $12_12, $06_06, $53_53, $53_53, $30_30, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53 ' Row 2 
              WORD      $30_30, $53_53, $53_53, $53_53, $21_21, $22_22, $53_53, $53_53, $53_53, $30_30, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53 ' Row 3 
              WORD      $30_30, $53_53, $53_53, $53_53, $04_04, $05_05, $53_53, $53_53, $53_53, $30_30, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53 ' Row 4 
              WORD      $30_30, $53_53, $53_53, $53_53, $04_04, $05_05, $53_53, $53_53, $53_53, $30_30, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53 ' Row 5 
              WORD      $10_10, $17_17, $18_18, $31_31, $0A_0A, $0B_0B, $34_34, $25_25, $26_26, $45_45, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53 ' Row 6 
              WORD      $53_53, $27_27, $28_28, $41_41, $42_42, $43_43, $44_44, $35_35, $36_36, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53 ' Row 7 
              WORD      $53_53, $07_07, $05_05, $14_14, $23_23, $24_24, $14_14, $04_04, $08_08, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53 ' Row 8 
              WORD      $53_53, $15_15, $05_05, $14_14, $06_06, $13_13, $14_14, $04_04, $16_16, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53 ' Row 9 
              WORD      $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53 ' Row 10
              WORD      $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53 ' Row 11

'Tilemap for engine failure/knock signal/temp (engine only)
tile_map4 WORD                                                                                                                                      
              WORD      $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53 ' Row 0 
              WORD      $40_40, $00_00, $01_01, $02_02, $02_02, $02_02, $02_02, $03_03, $00_00, $20_20, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53 ' Row 1 
              WORD      $30_30, $53_53, $53_53, $13_13, $11_11, $12_12, $06_06, $53_53, $53_53, $30_30, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53 ' Row 2 
              WORD      $30_30, $53_53, $53_53, $53_53, $21_21, $22_22, $53_53, $53_53, $53_53, $30_30, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53 ' Row 3 
              WORD      $30_30, $53_53, $53_53, $53_53, $04_04, $05_05, $53_53, $53_53, $53_53, $30_30, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53 ' Row 4 
              WORD      $30_30, $53_53, $53_53, $53_53, $04_04, $05_05, $53_53, $53_53, $53_53, $30_30, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53 ' Row 5 
              WORD      $10_10, $17_17, $18_18, $09_09, $0a_0a, $0b_0b, $0c_0c, $25_25, $26_26, $45_45, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53 ' Row 6 
              WORD      $53_53, $27_27, $28_28, $19_19, $1A_1A, $1B_1B, $1C_1C, $35_35, $36_36, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53 ' Row 7 
              WORD      $53_53, $07_07, $05_05, $14_14, $4E_4E, $47_47, $14_14, $04_04, $08_08, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53 ' Row 8 
              WORD      $53_53, $15_15, $05_05, $14_14, $06_06, $13_13, $14_14, $04_04, $16_16, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53 ' Row 9 
              WORD      $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53 ' Row 10
              WORD      $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53 ' Row 11

'Tilemap for induction failure/pressure over-differential (top 1/2 turbos, intercooler, & plumbing)
tile_map5 WORD                                                                                                                                      
              WORD      $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53 ' Row 0 
              WORD      $2d_2d, $37_37, $38_38, $49_49, $49_49, $49_49, $49_49, $4a_4a, $37_37, $6f_6f, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53 ' Row 1  
              WORD      $1d_1d, $53_53, $53_53, $54_54, $1e_1e, $1f_1f, $0f_0f, $53_53, $53_53, $1d_1d, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53 ' Row 2  
              WORD      $1d_1d, $53_53, $53_53, $53_53, $2e_2e, $2f_2f, $53_53, $53_53, $53_53, $1d_1d, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53 ' Row 3  
              WORD      $1d_1d, $53_53, $53_53, $53_53, $4b_4b, $4c_4c, $53_53, $53_53, $53_53, $1d_1d, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53 ' Row 4  
              WORD      $1d_1d, $53_53, $53_53, $53_53, $4b_4b, $4c_4c, $53_53, $53_53, $53_53, $1d_1d, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53 ' Row 5  
              WORD      $46_46, $2b_2b, $2c_2c, $09_09, $0a_0a, $0b_0b, $0c_0c, $29_29, $2a_2a, $48_48, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53 ' Row 6 
              WORD      $53_53, $27_27, $28_28, $41_41, $42_42, $43_43, $44_44, $35_35, $36_36, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53 ' Row 7 
              WORD      $53_53, $07_07, $05_05, $14_14, $23_23, $24_24, $14_14, $04_04, $08_08, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53 ' Row 8 
              WORD      $53_53, $15_15, $05_05, $14_14, $06_06, $13_13, $14_14, $04_04, $16_16, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53 ' Row 9 
              WORD      $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53 ' Row 10
              WORD      $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53 ' Row 11

'Tilemap for oil alarms - pressure/temp (engine & turbos)
tile_map6 WORD                                                                                                                                      
              WORD      $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53 ' Row 0 
              WORD      $40_40, $00_00, $01_01, $02_02, $02_02, $02_02, $02_02, $03_03, $00_00, $20_20, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53 ' Row 1 
              WORD      $30_30, $53_53, $53_53, $13_13, $11_11, $12_12, $06_06, $53_53, $53_53, $30_30, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53 ' Row 2 
              WORD      $30_30, $53_53, $53_53, $53_53, $21_21, $22_22, $53_53, $53_53, $53_53, $30_30, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53 ' Row 3 
              WORD      $30_30, $53_53, $53_53, $53_53, $04_04, $05_05, $53_53, $53_53, $53_53, $30_30, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53 ' Row 4 
              WORD      $30_30, $53_53, $53_53, $53_53, $04_04, $05_05, $53_53, $53_53, $53_53, $30_30, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53 ' Row 5 
              WORD      $10_10, $2B_2B, $2c_2c, $09_09, $0a_0a, $0b_0b, $0c_0c, $29_29, $2a_2a, $45_45, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53 ' Row 6 
              WORD      $53_53, $3b_3b, $3c_3c, $19_19, $1a_1a, $1b_1b, $1c_1c, $39_39, $3a_3a, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53 ' Row 7 
              WORD      $53_53, $07_07, $05_05, $14_14, $56_56, $47_47, $14_14, $04_04, $08_08, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53 ' Row 8 
              WORD      $53_53, $15_15, $05_05, $14_14, $06_06, $13_13, $14_14, $04_04, $16_16, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53 ' Row 9 
              WORD      $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53 ' Row 10
              WORD      $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53 ' Row 11
  
'Tilemap for boost control devices (tiles for vac actuators & immediate plumbing)
tile_map7 WORD                                                                                                                                      
              WORD      $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53 ' Row 0 
              WORD      $40_40, $00_00, $01_01, $02_02, $02_02, $02_02, $02_02, $03_03, $00_00, $20_20, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53 ' Row 1 
              WORD      $30_30, $53_53, $53_53, $54_54, $1e_1e, $1f_1f, $0f_0f, $53_53, $53_53, $30_30, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53 ' Row 2 
              WORD      $30_30, $53_53, $53_53, $53_53, $2e_2e, $2f_2f, $53_53, $53_53, $53_53, $30_30, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53 ' Row 3 
              WORD      $30_30, $53_53, $53_53, $53_53, $04_04, $05_05, $53_53, $53_53, $53_53, $30_30, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53 ' Row 4 
              WORD      $30_30, $53_53, $53_53, $53_53, $04_04, $05_05, $53_53, $53_53, $53_53, $30_30, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53 ' Row 5 
              WORD      $10_10, $17_17, $18_18, $31_31, $32_32, $33_33, $34_34, $25_25, $26_26, $45_45, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53 ' Row 6 
              WORD      $53_53, $27_27, $28_28, $41_41, $42_42, $43_43, $44_44, $35_35, $36_36, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53 ' Row 7 
              WORD      $53_53, $07_07, $05_05, $14_14, $23_23, $24_24, $14_14, $04_04, $08_08, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53 ' Row 8 
              WORD      $53_53, $15_15, $05_05, $3f_3f, $0f_0f, $54_54, $3f_3f, $04_04, $16_16, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53 ' Row 9 
              WORD      $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53 ' Row 10
              WORD      $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53, $53_53 ' Row 11


tile_bitmaps    LONG

' Extracted from file "profi_1px.bmp" at tile=(0, 0), size=(16, 16), palette index=(0)
profi_1px_tx0_ty0_bitmap    LONG
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%1_1_1_1_1_1_1_1_1_1_1_1_1_1_1_1
              LONG %%1_1_1_1_1_1_1_1_1_1_1_1_1_1_1_1
              LONG %%1_1_1_1_1_1_1_1_1_1_1_1_1_1_1_1
              LONG %%1_1_1_1_1_1_1_1_1_1_1_1_1_1_1_1
              LONG %%1_1_1_1_1_1_1_1_1_1_1_1_1_1_1_1
              LONG %%1_1_1_1_1_1_1_1_1_1_1_1_1_1_1_1
              LONG %%1_1_1_1_1_1_1_1_1_1_1_1_1_1_1_1
              LONG %%1_1_1_1_1_1_1_1_1_1_1_1_1_1_1_1
              LONG %%1_1_1_1_1_1_1_1_1_1_1_1_1_1_1_1
              LONG %%1_1_1_1_1_1_1_1_1_1_1_1_1_1_1_1
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0

' Extracted from file "profi_1px.bmp" at tile=(1, 0), size=(16, 16), palette index=(1)
profi_1px_tx1_ty0_bitmap    LONG
              LONG %%2_2_2_2_2_2_2_2_2_0_0_0_0_0_0_0
              LONG %%1_1_1_1_1_1_1_1_1_2_2_2_0_0_0_0
              LONG %%1_1_1_1_1_1_1_1_1_1_1_1_2_2_2_0
              LONG %%1_1_1_1_1_1_1_1_1_1_1_1_1_1_1_2
              LONG %%1_1_1_1_1_1_1_1_1_1_1_1_1_1_1_1
              LONG %%1_1_1_1_1_1_1_1_1_1_1_1_1_1_1_1
              LONG %%1_1_1_1_1_1_1_1_1_1_1_1_1_1_1_1
              LONG %%1_1_1_1_1_1_1_1_1_1_1_1_1_1_1_1
              LONG %%1_1_1_1_1_1_1_1_1_1_1_1_1_1_1_1
              LONG %%1_1_1_1_1_1_1_1_1_1_1_1_1_1_1_1
              LONG %%1_1_1_1_1_1_1_1_1_1_1_1_1_1_1_1
              LONG %%1_1_1_1_1_1_1_1_1_1_1_1_1_1_1_1
              LONG %%1_1_1_1_1_1_1_1_1_1_1_1_1_1_1_2
              LONG %%1_1_1_1_1_1_1_1_1_1_1_1_2_2_2_0
              LONG %%1_1_1_1_1_1_1_1_1_2_2_2_0_0_0_0
              LONG %%2_2_2_2_2_2_2_2_2_0_0_0_0_0_0_0

' Extracted from file "profi_1px.bmp" at tile=(2, 0), size=(16, 16), palette index=(2)
profi_1px_tx2_ty0_bitmap    LONG
              LONG %%2_2_2_2_2_2_2_2_2_2_2_2_2_2_2_2
              LONG %%1_1_1_1_1_1_1_1_1_1_1_1_1_1_1_1
              LONG %%1_1_1_1_1_1_1_1_1_1_1_1_1_1_1_1
              LONG %%1_1_1_1_1_1_1_1_1_1_1_1_1_1_1_1
              LONG %%1_1_1_1_1_1_1_1_1_1_1_1_1_1_1_1
              LONG %%1_1_1_1_1_1_1_1_1_1_1_1_1_1_1_1
              LONG %%1_1_1_1_1_1_1_1_1_1_1_1_1_1_1_1
              LONG %%1_1_1_1_1_1_1_1_1_1_1_1_1_1_1_1
              LONG %%1_1_1_1_1_1_1_1_1_1_1_1_1_1_1_1
              LONG %%1_1_1_1_1_1_1_1_1_1_1_1_1_1_1_1
              LONG %%1_1_1_1_1_1_1_1_1_1_1_1_1_1_1_1
              LONG %%1_1_1_1_1_1_1_1_1_1_1_1_1_1_1_1
              LONG %%1_1_1_1_1_1_1_1_1_1_1_1_1_1_1_1
              LONG %%1_1_1_1_1_1_1_1_1_1_1_1_1_1_1_1
              LONG %%1_1_1_1_1_1_1_1_1_1_1_1_1_1_1_1
              LONG %%2_2_2_2_2_2_2_2_2_2_2_2_2_2_2_2

' Extracted from file "profi_1px.bmp" at tile=(3, 0), size=(16, 16), palette index=(3)
profi_1px_tx3_ty0_bitmap    LONG
              LONG %%0_0_0_0_0_0_0_2_2_2_2_2_2_2_2_2
              LONG %%0_0_0_0_2_2_2_1_1_1_1_1_1_1_1_1
              LONG %%0_2_2_2_1_1_1_1_1_1_1_1_1_1_1_1
              LONG %%2_1_1_1_1_1_1_1_1_1_1_1_1_1_1_1
              LONG %%1_1_1_1_1_1_1_1_1_1_1_1_1_1_1_1
              LONG %%1_1_1_1_1_1_1_1_1_1_1_1_1_1_1_1
              LONG %%1_1_1_1_1_1_1_1_1_1_1_1_1_1_1_1
              LONG %%1_1_1_1_1_1_1_1_1_1_1_1_1_1_1_1
              LONG %%1_1_1_1_1_1_1_1_1_1_1_1_1_1_1_1
              LONG %%1_1_1_1_1_1_1_1_1_1_1_1_1_1_1_1
              LONG %%1_1_1_1_1_1_1_1_1_1_1_1_1_1_1_1
              LONG %%1_1_1_1_1_1_1_1_1_1_1_1_1_1_1_1
              LONG %%2_1_1_1_1_1_1_1_1_1_1_1_1_1_1_1
              LONG %%0_2_2_2_1_1_1_1_1_1_1_1_1_1_1_1
              LONG %%0_0_0_0_2_2_2_1_1_1_1_1_1_1_1_1
              LONG %%0_0_0_0_0_0_0_2_2_2_2_2_2_2_2_2

' Extracted from file "profi_1px.bmp" at tile=(4, 0), size=(16, 16), palette index=(4)
profi_1px_tx4_ty0_bitmap    LONG
              LONG %%1_1_1_1_1_1_0_0_0_0_0_0_0_0_0_0
              LONG %%1_1_1_1_1_1_0_0_0_0_0_0_0_0_0_0
              LONG %%1_1_1_1_1_1_0_0_0_0_0_0_0_0_0_0
              LONG %%1_1_1_1_1_1_0_0_0_0_0_0_0_0_0_0
              LONG %%1_1_1_1_1_1_0_0_0_0_0_0_0_0_0_0
              LONG %%1_1_1_1_1_1_0_0_0_0_0_0_0_0_0_0
              LONG %%1_1_1_1_1_1_0_0_0_0_0_0_0_0_0_0
              LONG %%1_1_1_1_1_1_0_0_0_0_0_0_0_0_0_0
              LONG %%1_1_1_1_1_1_0_0_0_0_0_0_0_0_0_0
              LONG %%1_1_1_1_1_1_0_0_0_0_0_0_0_0_0_0
              LONG %%1_1_1_1_1_1_0_0_0_0_0_0_0_0_0_0
              LONG %%1_1_1_1_1_1_0_0_0_0_0_0_0_0_0_0
              LONG %%1_1_1_1_1_1_0_0_0_0_0_0_0_0_0_0
              LONG %%1_1_1_1_1_1_0_0_0_0_0_0_0_0_0_0
              LONG %%1_1_1_1_1_1_0_0_0_0_0_0_0_0_0_0
              LONG %%1_1_1_1_1_1_0_0_0_0_0_0_0_0_0_0

' Extracted from file "profi_1px.bmp" at tile=(5, 0), size=(16, 16), palette index=(5)
profi_1px_tx5_ty0_bitmap    LONG
              LONG %%0_0_0_0_0_0_0_0_0_0_1_1_1_1_1_1
              LONG %%0_0_0_0_0_0_0_0_0_0_1_1_1_1_1_1
              LONG %%0_0_0_0_0_0_0_0_0_0_1_1_1_1_1_1
              LONG %%0_0_0_0_0_0_0_0_0_0_1_1_1_1_1_1
              LONG %%0_0_0_0_0_0_0_0_0_0_1_1_1_1_1_1
              LONG %%0_0_0_0_0_0_0_0_0_0_1_1_1_1_1_1
              LONG %%0_0_0_0_0_0_0_0_0_0_1_1_1_1_1_1
              LONG %%0_0_0_0_0_0_0_0_0_0_1_1_1_1_1_1
              LONG %%0_0_0_0_0_0_0_0_0_0_1_1_1_1_1_1
              LONG %%0_0_0_0_0_0_0_0_0_0_1_1_1_1_1_1
              LONG %%0_0_0_0_0_0_0_0_0_0_1_1_1_1_1_1
              LONG %%0_0_0_0_0_0_0_0_0_0_1_1_1_1_1_1
              LONG %%0_0_0_0_0_0_0_0_0_0_1_1_1_1_1_1
              LONG %%0_0_0_0_0_0_0_0_0_0_1_1_1_1_1_1
              LONG %%0_0_0_0_0_0_0_0_0_0_1_1_1_1_1_1
              LONG %%0_0_0_0_0_0_0_0_0_0_1_1_1_1_1_1

' Extracted from file "profi_1px.bmp" at tile=(6, 0), size=(16, 16), palette index=(6)
profi_1px_tx6_ty0_bitmap    LONG
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%0_0_0_0_0_0_0_0_1_2_1_0_0_0_0_0
              LONG %%0_0_0_0_0_0_0_0_1_2_1_0_0_0_0_0
              LONG %%0_0_0_0_0_0_0_1_1_2_1_1_0_0_0_0
              LONG %%0_0_0_0_0_0_0_1_1_2_1_1_0_0_0_0
              LONG %%0_0_0_0_0_0_1_1_1_2_1_1_1_0_0_0
              LONG %%0_0_0_0_0_0_1_1_1_2_1_1_1_0_0_0
              LONG %%0_0_0_0_0_0_1_1_1_2_1_1_1_1_1_0
              LONG %%0_0_0_0_0_0_1_1_1_2_1_1_1_0_0_0
              LONG %%0_0_0_0_0_0_1_1_1_2_1_1_1_0_0_0
              LONG %%0_0_0_0_0_0_0_1_1_2_1_1_0_0_0_0
              LONG %%0_0_0_0_0_0_0_1_1_2_1_1_0_0_0_0
              LONG %%0_0_0_0_0_0_0_0_1_2_1_0_0_0_0_0
              LONG %%0_0_0_0_0_0_0_0_1_2_1_0_0_0_0_0
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0

' Extracted from file "profi_1px.bmp" at tile=(7, 0), size=(16, 16), palette index=(7)
profi_1px_tx7_ty0_bitmap    LONG
              LONG %%1_1_1_1_1_1_0_0_0_0_0_0_0_0_0_0
              LONG %%1_1_1_1_1_1_0_0_0_0_0_0_0_0_0_0
              LONG %%1_1_1_1_1_1_0_0_0_0_0_0_0_0_0_0
              LONG %%1_1_1_1_1_1_0_0_0_0_0_0_0_0_0_0
              LONG %%1_1_1_1_1_1_0_0_0_0_0_0_0_0_0_0
              LONG %%1_1_1_1_1_1_0_0_0_0_0_0_0_0_0_0
              LONG %%1_1_1_1_1_1_2_0_0_0_0_0_0_0_0_0
              LONG %%1_1_1_1_1_1_2_1_0_0_0_0_0_0_0_0
              LONG %%1_1_1_1_1_1_2_1_1_0_0_0_0_0_0_0
              LONG %%1_1_1_1_1_1_2_1_1_1_0_0_0_0_0_0
              LONG %%1_1_1_1_1_1_2_1_1_1_1_0_0_0_0_0
              LONG %%1_1_1_1_1_1_2_1_1_1_1_1_0_0_0_0
              LONG %%1_1_1_1_1_1_2_1_1_1_1_1_1_0_0_0
              LONG %%1_1_1_1_1_1_2_1_1_1_1_1_1_1_0_0
              LONG %%1_1_1_1_1_1_2_1_1_1_1_1_1_1_1_0
              LONG %%1_1_1_1_1_1_2_1_1_1_1_1_1_1_1_1

' Extracted from file "profi_1px.bmp" at tile=(8, 0), size=(16, 16), palette index=(8)
profi_1px_tx8_ty0_bitmap    LONG
              LONG %%0_0_0_0_0_0_0_0_0_0_1_1_1_1_1_1
              LONG %%0_0_0_0_0_0_0_0_0_0_1_1_1_1_1_1
              LONG %%0_0_0_0_0_0_0_0_0_0_1_1_1_1_1_1
              LONG %%0_0_0_0_0_0_0_0_0_0_1_1_1_1_1_1
              LONG %%0_0_0_0_0_0_0_0_0_0_1_1_1_1_1_1
              LONG %%0_0_0_0_0_0_0_0_0_2_1_1_1_1_1_1
              LONG %%0_0_0_0_0_0_0_0_0_2_1_1_1_1_1_1
              LONG %%0_0_0_0_0_0_0_0_1_2_1_1_1_1_1_1
              LONG %%0_0_0_0_0_0_0_1_1_2_1_1_1_1_1_1
              LONG %%0_0_0_0_0_0_1_1_1_2_1_1_1_1_1_1
              LONG %%0_0_0_0_0_1_1_1_1_2_1_1_1_1_1_1
              LONG %%0_0_0_0_1_1_1_1_1_2_1_1_1_1_1_1
              LONG %%0_0_0_1_1_1_1_1_1_2_1_1_1_1_1_1
              LONG %%0_0_1_1_1_1_1_1_1_2_1_1_1_1_1_1
              LONG %%0_1_1_1_1_1_1_1_1_2_1_1_1_1_1_1
              LONG %%1_1_1_1_1_1_1_1_1_2_1_1_1_1_1_1

' Extracted from file "profi_1px.bmp" at tile=(9, 0), size=(16, 16), palette index=(9)
profi_1px_tx9_ty0_bitmap    LONG
              LONG %%1_1_0_0_0_0_0_0_1_1_1_0_0_0_0_0
              LONG %%1_1_1_0_0_0_0_0_0_1_1_1_0_0_0_0
              LONG %%0_1_1_1_0_0_0_0_0_0_1_1_1_0_0_0
              LONG %%0_0_1_1_1_0_0_0_0_0_0_1_1_1_0_0
              LONG %%0_0_0_1_1_1_0_0_0_0_0_0_1_1_1_0
              LONG %%0_0_0_0_1_1_1_0_0_0_0_0_0_1_1_1
              LONG %%0_0_0_0_0_1_1_1_0_0_0_0_0_0_1_1
              LONG %%0_0_0_0_0_0_1_1_1_0_0_0_0_0_0_1
              LONG %%1_0_0_0_0_0_0_1_1_1_0_0_0_0_0_0
              LONG %%1_1_0_0_0_0_0_0_1_1_1_0_0_0_0_0
              LONG %%1_1_1_0_0_0_0_0_0_1_1_1_0_0_0_0
              LONG %%2_1_1_1_0_0_0_0_0_0_1_1_1_0_0_0
              LONG %%2_2_1_1_1_0_0_0_0_0_0_1_1_1_0_0
              LONG %%2_2_2_1_1_1_0_0_0_0_0_0_1_1_1_0
              LONG %%2_2_2_2_1_1_1_0_0_0_0_0_0_1_1_1
              LONG %%2_2_2_2_2_1_1_1_0_0_0_0_0_0_1_1

' Extracted from file "profi_1px.bmp" at tile=(10, 0), size=(16, 16), palette index=(10)
profi_1px_tx10_ty0_bitmap    LONG
              LONG %%1_1_2_2_2_2_0_0_1_1_1_0_0_0_0_0
              LONG %%1_1_1_2_2_2_0_0_0_1_1_1_0_0_0_0
              LONG %%2_1_1_1_2_2_2_2_0_0_1_1_1_0_0_0
              LONG %%2_2_1_1_1_2_2_2_2_0_0_1_1_1_0_0
              LONG %%2_2_2_1_1_1_2_2_2_0_0_0_1_1_1_0
              LONG %%2_2_2_2_1_1_1_2_2_0_0_0_0_1_1_1
              LONG %%2_2_2_2_2_1_1_1_2_0_0_0_0_0_1_1
              LONG %%2_2_2_2_2_2_1_1_1_2_0_0_0_0_0_1
              LONG %%1_2_2_2_2_2_2_1_1_1_2_0_0_0_0_0
              LONG %%1_1_2_2_2_2_2_2_1_1_1_2_0_0_0_0
              LONG %%1_1_1_2_2_0_2_2_2_1_1_1_2_0_0_3
              LONG %%2_1_1_1_0_0_0_2_2_2_1_1_1_2_3_3
              LONG %%2_2_1_1_1_0_0_0_2_2_2_1_1_1_3_3
              LONG %%2_2_0_1_1_1_0_0_0_2_2_2_1_1_1_3
              LONG %%0_0_0_0_1_1_1_0_0_0_2_3_3_1_1_1
              LONG %%0_0_0_0_0_1_1_1_0_3_3_3_3_3_1_1

' Extracted from file "profi_1px.bmp" at tile=(11, 0), size=(16, 16), palette index=(11)
profi_1px_tx11_ty0_bitmap    LONG
              LONG %%1_1_0_0_0_0_0_0_1_1_1_2_2_2_2_2
              LONG %%1_1_1_0_0_0_0_0_0_1_1_1_2_2_2_2
              LONG %%0_1_1_1_0_0_0_0_2_2_1_1_1_2_2_2
              LONG %%0_0_1_1_1_0_0_2_2_2_2_1_1_1_2_2
              LONG %%0_0_0_1_1_1_0_2_2_2_2_2_1_1_1_2
              LONG %%0_0_0_0_1_1_1_2_2_2_2_2_2_1_1_1
              LONG %%0_0_0_0_0_1_1_1_2_2_2_2_2_2_1_1
              LONG %%0_0_0_0_0_0_1_1_1_2_2_2_2_2_2_1
              LONG %%1_0_0_0_0_2_2_1_1_1_2_2_2_2_2_2
              LONG %%1_1_0_0_2_2_2_2_1_1_1_2_2_2_2_2
              LONG %%1_1_1_3_2_2_2_2_2_1_1_1_2_2_2_2
              LONG %%3_1_1_1_2_2_2_2_2_0_1_1_1_2_2_2
              LONG %%3_3_1_1_1_2_2_2_0_0_0_1_1_1_2_2
              LONG %%3_3_3_1_1_1_2_0_0_0_0_0_1_1_1_2
              LONG %%3_3_3_3_1_1_1_0_0_0_0_0_0_1_1_1
              LONG %%3_3_3_3_3_1_1_1_0_0_0_0_0_0_1_1

' Extracted from file "profi_1px.bmp" at tile=(12, 0), size=(16, 16), palette index=(12)
profi_1px_tx12_ty0_bitmap    LONG
              LONG %%1_1_0_0_0_0_0_0_1_1_1_0_0_0_0_0
              LONG %%1_1_1_0_0_0_0_0_0_1_1_1_0_0_0_0
              LONG %%0_1_1_1_0_0_0_0_0_0_1_1_1_0_0_0
              LONG %%0_0_1_1_1_0_0_0_0_0_0_1_1_1_0_0
              LONG %%0_0_0_1_1_1_0_0_0_0_0_0_1_1_1_0
              LONG %%0_0_0_0_1_1_1_0_0_0_0_0_0_1_1_1
              LONG %%0_0_0_0_0_1_1_1_0_0_0_0_0_0_1_1
              LONG %%0_0_0_0_0_0_1_1_1_0_0_0_0_0_0_1
              LONG %%1_0_0_0_0_0_0_1_1_1_0_0_0_0_0_0
              LONG %%1_1_0_0_0_0_0_0_1_1_1_0_0_0_0_0
              LONG %%1_1_1_0_0_0_0_0_0_1_1_1_0_2_2_2
              LONG %%0_1_1_1_0_0_0_0_0_0_1_1_1_2_2_2
              LONG %%0_0_1_1_1_0_0_0_0_0_0_1_1_1_2_2
              LONG %%0_0_0_1_1_1_0_0_0_0_2_2_1_1_1_2
              LONG %%0_0_0_0_1_1_1_0_0_2_2_2_2_1_1_1
              LONG %%0_0_0_0_0_1_1_1_2_2_2_2_2_2_1_1

' Extracted from file "profi_1px.bmp" at tile=(13, 0), size=(16, 16), palette index=(13)
profi_1px_tx13_ty0_bitmap    LONG
              LONG %%1_1_0_0_0_0_0_0_1_1_1_0_0_0_0_0
              LONG %%1_1_1_0_0_0_0_0_0_1_1_1_0_0_0_0
              LONG %%0_1_1_1_0_0_0_0_0_0_1_1_1_0_0_0
              LONG %%0_0_1_1_1_0_0_0_0_0_0_1_1_1_0_0
              LONG %%0_0_0_1_1_1_0_0_0_0_0_0_1_1_1_0
              LONG %%0_0_0_0_1_1_1_0_0_0_0_0_0_1_1_1
              LONG %%0_0_0_0_0_1_1_1_0_0_0_0_0_0_1_1
              LONG %%0_0_0_0_0_0_1_1_1_0_0_0_0_0_0_1
              LONG %%1_0_0_0_0_0_0_1_1_1_0_0_0_0_0_0
              LONG %%1_1_0_0_0_0_0_0_1_1_1_0_0_0_0_0
              LONG %%1_1_1_0_0_0_0_0_0_1_1_1_0_0_0_0
              LONG %%0_1_1_1_0_0_0_0_0_0_1_1_1_0_0_0
              LONG %%0_0_1_1_1_0_0_0_0_0_0_1_1_1_0_0
              LONG %%0_0_0_1_1_1_0_0_0_0_0_0_1_1_1_0
              LONG %%0_0_0_0_1_1_1_0_0_0_0_0_0_1_1_1
              LONG %%0_0_0_0_0_1_1_1_0_0_0_0_0_0_1_1

' Extracted from file "profi_1px.bmp" at tile=(14, 0), size=(16, 16), palette index=(14)
profi_1px_tx14_ty0_bitmap    LONG
              LONG %%2_2_0_0_0_0_0_0_2_2_2_1_1_1_1_1
              LONG %%2_2_2_0_0_0_0_0_0_2_2_2_1_1_1_1
              LONG %%0_2_2_2_0_0_0_0_0_0_2_2_2_1_1_1
              LONG %%0_0_2_2_2_0_0_0_0_0_1_2_2_2_1_1
              LONG %%0_0_0_2_2_2_0_0_0_0_1_1_2_2_2_1
              LONG %%0_0_0_0_2_2_2_0_0_0_1_1_1_2_2_2
              LONG %%0_0_0_0_0_2_2_2_0_1_1_1_1_1_2_2
              LONG %%0_0_0_0_0_0_2_2_2_1_1_1_1_1_1_2
              LONG %%2_0_0_0_0_0_0_2_2_2_1_1_1_1_1_1
              LONG %%2_2_0_0_0_0_1_1_2_2_2_1_1_1_1_1
              LONG %%2_2_2_0_0_1_1_1_1_2_2_2_1_1_1_1
              LONG %%0_2_2_2_1_1_1_1_1_1_2_2_2_1_1_1
              LONG %%0_0_2_2_2_1_1_1_1_1_1_2_2_2_1_1
              LONG %%0_0_1_2_2_2_1_1_1_1_1_1_2_2_2_1
              LONG %%0_1_1_1_2_2_2_1_1_1_1_1_1_2_2_2
              LONG %%1_1_1_1_1_2_2_2_1_1_1_1_1_1_2_2

' Extracted from file "profi_1px.bmp" at tile=(15, 0), size=(16, 16), palette index=(15)
profi_1px_tx15_ty0_bitmap    LONG
              LONG %%1_1_0_0_0_0_0_0_1_1_1_0_0_0_0_0
              LONG %%1_1_1_0_0_0_0_0_0_1_1_1_0_0_0_0
              LONG %%0_1_1_1_0_0_0_0_2_3_1_1_1_0_0_0
              LONG %%0_0_1_1_1_0_0_0_2_3_2_1_1_1_0_0
              LONG %%0_0_0_1_1_1_0_2_2_3_2_2_1_1_1_0
              LONG %%0_0_0_0_1_1_1_2_2_3_2_2_0_1_1_1
              LONG %%0_0_0_0_0_1_1_1_2_3_2_2_2_0_1_1
              LONG %%0_0_0_0_0_0_1_1_1_3_2_2_2_0_0_1
              LONG %%1_0_0_0_0_0_2_1_1_1_2_2_2_2_2_0
              LONG %%1_1_0_0_0_0_2_2_1_1_1_2_2_0_0_0
              LONG %%1_1_1_0_0_0_2_2_2_1_1_1_2_0_0_0
              LONG %%0_1_1_1_0_0_0_2_2_3_1_1_1_0_0_0
              LONG %%0_0_1_1_1_0_0_2_2_3_2_1_1_1_0_0
              LONG %%0_0_0_1_1_1_0_0_2_3_2_0_1_1_1_0
              LONG %%0_0_0_0_1_1_1_0_2_3_2_0_0_1_1_1
              LONG %%0_0_0_0_0_1_1_1_0_0_0_0_0_0_1_1

' Extracted from file "profi_1px.bmp" at tile=(0, 1), size=(16, 16), palette index=(16)
profi_1px_tx0_ty1_bitmap    LONG
              LONG %%0_0_0_1_1_1_1_1_1_1_1_1_1_0_0_0
              LONG %%0_0_0_1_1_1_1_1_1_1_1_1_1_0_0_0
              LONG %%0_0_0_1_1_1_1_1_1_1_1_1_1_0_0_0
              LONG %%1_1_1_1_1_1_1_1_1_1_1_1_1_0_0_0
              LONG %%1_1_1_1_1_1_1_1_1_1_1_1_1_0_0_0
              LONG %%1_1_1_1_1_1_1_1_1_1_1_1_1_0_0_0
              LONG %%1_1_1_1_1_1_1_1_1_1_1_1_1_0_0_0
              LONG %%1_1_1_1_1_1_1_1_1_1_1_1_1_0_0_0
              LONG %%1_1_1_1_1_1_1_1_1_1_1_1_0_0_0_0
              LONG %%1_1_1_1_1_1_1_1_1_1_1_1_0_0_0_0
              LONG %%1_1_1_1_1_1_1_1_1_1_1_0_0_0_0_0
              LONG %%1_1_1_1_1_1_1_1_1_1_0_0_0_0_0_0
              LONG %%1_1_1_1_1_1_1_1_0_0_0_0_0_0_0_0
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0

' Extracted from file "profi_1px.bmp" at tile=(1, 1), size=(16, 16), palette index=(17)
profi_1px_tx1_ty1_bitmap    LONG
              LONG %%1_1_1_1_1_1_0_0_0_0_0_0_0_0_0_0
              LONG %%1_1_1_1_1_1_0_0_0_0_0_0_0_0_0_0
              LONG %%1_1_1_1_1_1_0_0_0_0_0_0_0_0_0_0
              LONG %%1_1_1_1_1_1_0_0_0_0_0_0_0_0_0_0
              LONG %%1_1_1_1_1_1_0_0_0_0_0_0_0_0_0_0
              LONG %%1_1_1_1_1_1_0_0_0_0_0_0_0_0_0_0
              LONG %%1_1_1_1_1_1_1_0_0_0_0_0_0_0_0_0
              LONG %%1_1_1_1_1_1_2_1_0_0_0_0_0_0_0_0
              LONG %%1_1_1_1_1_1_2_1_1_0_0_0_0_0_0_0
              LONG %%1_1_1_1_1_1_2_1_1_1_0_0_0_0_0_0
              LONG %%1_1_1_1_1_1_2_1_1_1_1_0_0_0_0_0
              LONG %%1_1_1_1_1_1_2_1_1_1_1_1_0_0_0_0
              LONG %%1_1_1_1_1_1_2_1_1_1_1_1_1_0_0_0
              LONG %%1_1_1_1_1_1_2_1_1_1_1_1_1_1_0_0
              LONG %%1_1_1_1_1_1_2_1_1_1_1_1_1_1_1_0
              LONG %%1_1_1_1_1_1_2_1_1_1_1_1_1_1_1_1

' Extracted from file "profi_1px.bmp" at tile=(2, 1), size=(16, 16), palette index=(18)
profi_1px_tx2_ty1_bitmap    LONG
              LONG %%0_0_0_0_0_0_0_0_0_0_1_1_1_1_1_1
              LONG %%0_0_0_0_0_0_0_0_0_0_1_1_1_1_1_1
              LONG %%0_0_0_0_0_0_0_0_0_0_1_1_1_1_1_1
              LONG %%0_0_0_0_0_0_0_0_0_0_1_1_1_1_1_1
              LONG %%0_0_0_0_0_0_0_0_0_0_1_1_1_1_1_1
              LONG %%0_0_0_0_0_0_0_0_0_0_1_1_1_1_1_1
              LONG %%0_0_0_0_0_0_0_0_0_1_1_1_1_1_1_1
              LONG %%0_0_0_0_0_0_0_0_1_2_1_1_1_1_1_1
              LONG %%0_0_0_0_0_0_0_1_1_2_1_1_1_1_1_1
              LONG %%0_0_0_0_0_0_1_1_1_2_1_1_1_1_1_1
              LONG %%0_0_0_0_0_1_1_1_1_2_1_1_1_1_1_1
              LONG %%0_0_0_0_1_1_1_1_1_2_1_1_1_1_1_1
              LONG %%0_0_0_1_1_1_1_1_1_2_1_1_1_1_1_1
              LONG %%0_0_1_1_1_1_1_1_1_2_1_1_1_1_1_1
              LONG %%0_1_1_1_1_1_1_1_1_2_1_1_1_1_1_1
              LONG %%1_1_1_1_1_1_1_1_1_2_1_1_1_1_1_1

' Extracted from file "profi_1px.bmp" at tile=(3, 1), size=(16, 16), palette index=(19)
profi_1px_tx3_ty1_bitmap    LONG
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%0_0_0_0_0_1_2_1_0_0_0_0_0_0_0_0
              LONG %%0_0_0_0_0_1_2_1_0_0_0_0_0_0_0_0
              LONG %%0_0_0_0_1_1_2_1_1_0_0_0_0_0_0_0
              LONG %%0_0_0_0_1_1_2_1_1_0_0_0_0_0_0_0
              LONG %%0_0_0_1_1_1_2_1_1_1_0_0_0_0_0_0
              LONG %%0_0_0_1_1_1_2_1_1_1_0_0_0_0_0_0
              LONG %%0_1_1_1_1_1_2_1_1_1_0_0_0_0_0_0
              LONG %%0_0_0_1_1_1_2_1_1_1_0_0_0_0_0_0
              LONG %%0_0_0_1_1_1_2_1_1_1_0_0_0_0_0_0
              LONG %%0_0_0_0_1_1_2_1_1_0_0_0_0_0_0_0
              LONG %%0_0_0_0_1_1_2_1_1_0_0_0_0_0_0_0
              LONG %%0_0_0_0_0_1_2_1_0_0_0_0_0_0_0_0
              LONG %%0_0_0_0_0_1_2_1_0_0_0_0_0_0_0_0
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0

' Extracted from file "profi_1px.bmp" at tile=(4, 1), size=(16, 16), palette index=(20)
profi_1px_tx4_ty1_bitmap    LONG
              LONG %%0_0_0_0_1_1_1_1_1_1_1_1_0_0_0_0
              LONG %%0_0_0_0_1_1_1_1_1_1_1_1_0_0_0_0
              LONG %%0_0_0_0_1_1_1_1_1_1_1_1_0_0_0_0
              LONG %%0_0_0_0_1_1_1_1_1_1_1_1_0_0_0_0
              LONG %%0_0_0_0_1_1_1_1_1_1_1_1_0_0_0_0
              LONG %%0_0_0_0_1_1_1_1_1_1_1_1_0_0_0_0
              LONG %%0_0_0_0_1_1_1_1_1_1_1_1_0_0_0_0
              LONG %%0_0_0_0_1_1_1_1_1_1_1_1_0_0_0_0
              LONG %%0_0_0_0_1_1_1_1_1_1_1_1_0_0_0_0
              LONG %%0_0_0_0_1_1_1_1_1_1_1_1_0_0_0_0
              LONG %%0_0_0_0_1_1_1_1_1_1_1_1_0_0_0_0
              LONG %%0_0_0_0_1_1_1_1_1_1_1_1_0_0_0_0
              LONG %%0_0_0_0_1_1_1_1_1_1_1_1_0_0_0_0
              LONG %%0_0_0_0_1_1_1_1_1_1_1_1_0_0_0_0
              LONG %%0_0_0_0_1_1_1_1_1_1_1_1_0_0_0_0
              LONG %%0_0_0_0_1_1_1_1_1_1_1_1_0_0_0_0

' Extracted from file "profi_1px.bmp" at tile=(5, 1), size=(16, 16), palette index=(21)
profi_1px_tx5_ty1_bitmap    LONG
              LONG %%1_1_1_1_1_1_2_1_1_1_1_1_1_1_1_1
              LONG %%1_1_1_1_1_1_2_1_1_1_1_1_1_1_1_1
              LONG %%1_1_1_1_1_1_2_1_1_1_1_1_1_1_1_1
              LONG %%1_1_1_1_1_1_2_1_1_1_1_1_1_1_1_1
              LONG %%1_1_1_1_1_1_0_1_1_1_1_1_1_1_1_1
              LONG %%1_1_1_1_1_1_0_0_1_1_1_1_1_1_1_1
              LONG %%1_1_1_1_1_1_0_0_0_1_1_1_1_1_1_1
              LONG %%1_1_1_1_1_1_0_0_0_0_1_1_1_1_1_1
              LONG %%1_1_1_1_1_1_0_0_0_0_0_1_1_1_1_1
              LONG %%1_1_1_1_1_1_0_0_0_0_0_0_1_1_1_1
              LONG %%1_1_1_1_1_1_0_0_0_0_0_0_0_1_1_1
              LONG %%1_1_1_1_1_1_0_0_0_0_0_0_0_0_1_1
              LONG %%1_1_1_1_1_1_0_0_0_0_0_0_0_0_0_1
              LONG %%1_1_1_1_1_1_0_0_0_0_0_0_0_0_0_0
              LONG %%1_1_1_1_1_1_0_0_0_0_0_0_0_0_0_0
              LONG %%1_1_1_1_1_1_0_0_0_0_0_0_0_0_0_0

' Extracted from file "profi_1px.bmp" at tile=(6, 1), size=(16, 16), palette index=(22)
profi_1px_tx6_ty1_bitmap    LONG
              LONG %%1_1_1_1_1_1_1_1_1_2_1_1_1_1_1_1
              LONG %%1_1_1_1_1_1_1_1_1_2_1_1_1_1_1_1
              LONG %%1_1_1_1_1_1_1_1_1_2_1_1_1_1_1_1
              LONG %%1_1_1_1_1_1_1_1_1_2_1_1_1_1_1_1
              LONG %%1_1_1_1_1_1_1_1_1_0_1_1_1_1_1_1
              LONG %%1_1_1_1_1_1_1_1_0_0_1_1_1_1_1_1
              LONG %%1_1_1_1_1_1_1_0_0_0_1_1_1_1_1_1
              LONG %%1_1_1_1_1_1_0_0_0_0_1_1_1_1_1_1
              LONG %%1_1_1_1_1_0_0_0_0_0_1_1_1_1_1_1
              LONG %%1_1_1_1_0_0_0_0_0_0_1_1_1_1_1_1
              LONG %%1_1_1_0_0_0_0_0_0_0_1_1_1_1_1_1
              LONG %%1_1_0_0_0_0_0_0_0_0_1_1_1_1_1_1
              LONG %%1_0_0_0_0_0_0_0_0_0_1_1_1_1_1_1
              LONG %%0_0_0_0_0_0_0_0_0_0_1_1_1_1_1_1
              LONG %%0_0_0_0_0_0_0_0_0_0_1_1_1_1_1_1
              LONG %%0_0_0_0_0_0_0_0_0_0_1_1_1_1_1_1

' Extracted from file "profi_1px.bmp" at tile=(7, 1), size=(16, 16), palette index=(23)
profi_1px_tx7_ty1_bitmap    LONG
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%1_1_1_1_1_1_0_0_0_0_0_0_0_0_0_0
              LONG %%1_1_1_1_1_1_0_0_0_0_0_0_0_0_0_0
              LONG %%1_1_1_1_1_1_0_0_0_0_0_0_0_0_0_0
              LONG %%2_2_2_2_2_2_1_1_1_1_1_1_1_1_1_1
              LONG %%1_1_1_1_1_1_1_1_1_1_1_1_1_1_1_1
              LONG %%1_1_1_1_1_1_1_1_1_1_1_1_1_1_1_1
              LONG %%1_1_1_1_1_1_1_1_1_1_1_1_1_1_1_1
              LONG %%1_1_1_1_1_1_1_1_1_1_1_1_1_1_1_1
              LONG %%1_1_1_1_1_1_1_1_1_1_1_1_1_1_1_1
              LONG %%1_1_1_1_1_1_1_1_1_1_1_1_1_1_1_1
              LONG %%2_1_1_1_1_1_1_1_1_1_1_1_1_1_1_1
              LONG %%2_2_2_2_2_0_0_0_1_1_1_1_1_1_1_1
              LONG %%2_2_2_2_2_2_0_0_0_0_0_0_0_0_0_0
              LONG %%2_2_2_2_2_2_0_0_0_0_0_0_0_0_0_0
              LONG %%2_2_2_2_2_2_2_0_0_0_0_0_0_0_0_0

' Extracted from file "profi_1px.bmp" at tile=(8, 1), size=(16, 16), palette index=(24)
profi_1px_tx8_ty1_bitmap    LONG
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%0_0_0_0_0_0_0_0_0_0_1_1_1_1_1_1
              LONG %%0_0_0_0_0_0_0_0_0_0_1_1_1_1_1_1
              LONG %%0_0_0_0_0_0_0_0_0_0_1_1_1_1_1_1
              LONG %%0_0_1_1_1_1_1_1_1_1_2_2_2_2_2_2
              LONG %%0_1_1_1_1_1_1_1_1_1_1_1_1_1_1_1
              LONG %%0_1_1_1_1_1_1_1_1_1_1_1_1_1_1_1
              LONG %%0_1_1_1_1_1_1_1_1_1_1_1_1_1_1_1
              LONG %%0_0_1_1_1_1_1_1_1_1_1_1_1_1_1_1
              LONG %%0_0_0_0_0_1_1_1_1_1_1_1_1_1_1_1
              LONG %%0_0_0_0_0_0_0_0_0_0_0_1_1_1_1_1
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_2_2_2_2
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_2_2_2_2
              LONG %%0_0_0_0_0_0_0_0_0_0_0_2_2_2_2_2
              LONG %%0_0_0_0_0_0_0_0_0_0_0_2_2_2_2_2
              LONG %%0_0_0_0_0_0_0_0_0_0_2_2_2_2_2_2

' Extracted from file "profi_1px.bmp" at tile=(9, 1), size=(16, 16), palette index=(25)
profi_1px_tx9_ty1_bitmap    LONG
              LONG %%2_2_3_3_3_3_3_3_2_2_2_0_0_0_0_0
              LONG %%2_2_2_3_3_3_3_3_3_2_2_2_0_0_0_0
              LONG %%3_2_2_2_3_3_3_3_3_0_2_2_2_0_0_0
              LONG %%3_3_2_2_2_3_3_3_1_1_1_2_2_2_1_1
              LONG %%3_3_3_2_2_2_3_1_1_1_1_1_2_2_2_1
              LONG %%3_3_3_3_2_2_2_1_1_1_1_1_1_2_2_2
              LONG %%3_3_3_3_3_2_2_2_1_1_1_1_1_1_2_2
              LONG %%3_3_3_3_1_1_2_2_2_1_1_1_1_1_1_2
              LONG %%2_3_3_1_1_1_1_2_2_2_1_1_1_1_1_1
              LONG %%2_2_1_1_1_1_1_1_2_2_2_1_1_1_1_1
              LONG %%2_2_2_1_1_1_1_1_1_2_2_2_1_1_1_1
              LONG %%1_2_2_2_1_1_1_1_1_1_2_2_2_1_1_1
              LONG %%1_1_2_2_2_1_1_1_1_1_1_2_2_2_1_1
              LONG %%0_0_0_2_2_2_1_1_1_1_1_1_2_2_2_0
              LONG %%0_0_0_0_2_2_2_1_1_1_1_1_0_2_2_2
              LONG %%0_0_0_0_1_2_2_2_1_1_1_1_0_0_2_2

' Extracted from file "profi_1px.bmp" at tile=(10, 1), size=(16, 16), palette index=(26)
profi_1px_tx10_ty1_bitmap    LONG
              LONG %%2_2_1_1_1_1_1_1_2_2_2_1_1_1_1_1
              LONG %%2_2_2_1_1_1_1_1_1_2_2_2_1_1_1_1
              LONG %%1_2_2_2_1_1_1_1_1_1_2_2_2_1_1_1
              LONG %%1_1_2_2_2_1_1_1_1_1_1_2_2_2_1_1
              LONG %%1_1_1_2_2_2_1_1_1_1_1_1_2_2_2_1
              LONG %%1_1_1_1_2_2_2_1_1_1_1_1_1_2_2_2
              LONG %%1_1_1_1_1_2_2_2_1_1_1_1_1_1_2_2
              LONG %%1_1_1_1_1_1_2_2_2_1_1_1_1_1_1_2
              LONG %%2_1_1_1_1_1_1_2_2_2_1_1_1_1_1_1
              LONG %%2_2_1_1_1_1_1_1_2_2_2_1_1_1_1_1
              LONG %%2_2_2_1_1_1_1_1_1_2_2_2_1_1_1_1
              LONG %%1_2_2_2_1_1_1_1_1_1_2_2_2_1_1_1
              LONG %%1_1_2_2_2_1_1_1_1_1_1_2_2_2_1_3
              LONG %%1_1_1_2_2_2_1_1_1_1_1_1_2_2_2_0
              LONG %%1_1_1_1_2_2_2_1_1_1_1_1_1_2_2_2
              LONG %%1_1_1_1_1_2_2_2_1_1_1_0_0_0_2_2

' Extracted from file "profi_1px.bmp" at tile=(11, 1), size=(16, 16), palette index=(27)
profi_1px_tx11_ty1_bitmap    LONG
              LONG %%2_2_1_1_1_1_1_1_2_2_2_1_1_1_1_1
              LONG %%2_2_2_1_1_1_1_1_1_2_2_2_1_1_1_1
              LONG %%1_2_2_2_1_1_1_1_1_1_2_2_2_1_1_1
              LONG %%1_1_2_2_2_1_1_1_1_1_1_2_2_2_1_1
              LONG %%1_1_1_2_2_2_1_1_1_1_1_1_2_2_2_1
              LONG %%1_1_1_1_2_2_2_1_1_1_1_1_1_2_2_2
              LONG %%1_1_1_1_1_2_2_2_1_1_1_1_1_1_2_2
              LONG %%1_1_1_1_1_1_2_2_2_1_1_1_1_1_1_2
              LONG %%2_1_1_1_1_1_1_2_2_2_1_1_1_1_1_1
              LONG %%2_2_1_1_1_1_1_1_2_2_2_1_1_1_1_1
              LONG %%2_2_2_1_1_1_1_1_1_2_2_2_1_1_1_1
              LONG %%1_2_2_2_1_1_1_1_1_1_2_2_2_1_1_1
              LONG %%3_1_2_2_2_1_1_1_1_1_1_2_2_2_1_1
              LONG %%0_0_1_2_2_2_1_1_1_1_1_1_2_2_2_1
              LONG %%0_0_0_1_2_2_2_1_1_1_1_1_1_2_2_2
              LONG %%0_0_0_0_0_2_2_2_1_1_1_1_1_1_2_2

' Extracted from file "profi_1px.bmp" at tile=(12, 1), size=(16, 16), palette index=(28)
profi_1px_tx12_ty1_bitmap    LONG
              LONG %%2_2_0_0_0_0_0_3_2_2_2_3_3_3_3_3
              LONG %%2_2_2_0_0_0_0_3_3_2_2_2_3_3_3_3
              LONG %%0_2_2_2_0_0_0_3_3_3_2_2_2_3_3_3
              LONG %%1_1_2_2_2_1_1_1_3_3_3_2_2_2_3_3
              LONG %%1_1_1_2_2_2_1_1_1_3_3_3_2_2_2_3
              LONG %%1_1_1_1_2_2_2_1_1_1_3_3_3_2_2_2
              LONG %%1_1_1_1_1_2_2_2_1_1_1_3_3_3_2_2
              LONG %%1_1_1_1_1_1_2_2_2_1_1_1_3_3_3_2
              LONG %%2_1_1_1_1_1_1_2_2_2_1_1_1_3_3_3
              LONG %%2_2_1_1_1_1_1_1_2_2_2_1_1_1_3_3
              LONG %%2_2_2_1_1_1_1_1_1_2_2_2_1_1_1_3
              LONG %%1_2_2_2_1_1_1_1_1_1_2_2_2_1_1_1
              LONG %%1_1_2_2_2_1_1_1_1_1_1_2_2_2_1_1
              LONG %%0_0_0_2_2_2_1_1_1_1_1_1_2_2_2_0
              LONG %%0_0_0_0_2_2_2_1_1_1_1_1_0_2_2_2
              LONG %%0_0_0_0_1_2_2_2_1_1_1_1_0_0_2_2

' Extracted from file "profi_1px.bmp" at tile=(13, 1), size=(16, 16), palette index=(29)
profi_1px_tx13_ty1_bitmap    LONG
              LONG %%2_2_0_1_1_1_1_1_2_2_2_1_1_0_0_0
              LONG %%2_2_2_1_1_1_1_1_1_2_2_2_1_0_0_0
              LONG %%0_2_2_2_1_1_1_1_1_1_2_2_2_0_0_0
              LONG %%0_0_2_2_2_1_1_1_1_1_1_2_2_2_0_0
              LONG %%0_0_0_2_2_2_1_1_1_1_1_1_2_2_2_0
              LONG %%0_0_0_1_2_2_2_1_1_1_1_1_1_2_2_2
              LONG %%0_0_0_1_1_2_2_2_1_1_1_1_1_0_2_2
              LONG %%0_0_0_1_1_1_2_2_2_1_1_1_1_0_0_2
              LONG %%2_0_0_1_1_1_1_2_2_2_1_1_1_0_0_0
              LONG %%2_2_0_1_1_1_1_1_2_2_2_1_1_0_0_0
              LONG %%2_2_2_1_1_1_1_1_1_2_2_2_1_0_0_0
              LONG %%0_2_2_2_1_1_1_1_1_1_2_2_2_0_0_0
              LONG %%0_0_2_2_2_1_1_1_1_1_1_2_2_2_0_0
              LONG %%0_0_0_2_2_2_1_1_1_1_1_1_2_2_2_0
              LONG %%0_0_0_1_2_2_2_1_1_1_1_1_1_2_2_2
              LONG %%0_0_0_1_1_2_2_2_1_1_1_1_1_0_2_2

' Extracted from file "profi_1px.bmp" at tile=(14, 1), size=(16, 16), palette index=(30)
profi_1px_tx14_ty1_bitmap    LONG
              LONG %%2_2_1_1_1_1_0_0_2_2_2_0_0_0_0_0
              LONG %%2_2_2_1_1_1_0_0_0_2_2_2_0_0_0_0
              LONG %%1_2_2_2_1_1_0_0_0_0_2_2_2_0_0_0
              LONG %%1_1_2_2_2_1_0_0_0_0_0_2_2_2_0_0
              LONG %%1_1_1_2_2_2_0_0_0_0_0_0_2_2_2_0
              LONG %%1_1_1_1_2_2_2_0_0_0_0_0_0_2_2_2
              LONG %%1_1_1_1_1_2_2_2_0_0_0_0_0_0_2_2
              LONG %%1_1_1_1_1_1_2_2_2_0_0_0_0_0_0_2
              LONG %%2_1_1_1_1_1_1_2_2_2_0_0_0_0_0_0
              LONG %%2_2_1_1_1_1_1_1_2_2_2_0_0_0_0_0
              LONG %%2_2_2_1_1_1_1_1_1_2_2_2_0_0_0_0
              LONG %%1_2_2_2_1_1_1_1_1_1_2_2_2_0_0_0
              LONG %%1_1_2_2_2_1_1_1_1_1_1_2_2_2_0_0
              LONG %%1_1_1_2_2_2_1_1_1_1_1_1_2_2_2_0
              LONG %%1_1_1_1_2_2_2_1_1_1_1_1_1_2_2_2
              LONG %%1_1_1_1_1_2_2_2_1_1_1_1_1_1_2_2

' Extracted from file "profi_1px.bmp" at tile=(15, 1), size=(16, 16), palette index=(31)
profi_1px_tx15_ty1_bitmap    LONG
              LONG %%2_2_0_0_0_0_0_0_2_2_2_1_1_1_1_1
              LONG %%2_2_2_0_0_0_0_0_0_2_2_2_1_1_1_1
              LONG %%0_2_2_2_0_0_0_0_0_0_2_2_2_1_1_1
              LONG %%0_0_2_2_2_0_0_0_0_0_1_2_2_2_1_1
              LONG %%0_0_0_2_2_2_0_0_0_0_1_1_2_2_2_1
              LONG %%0_0_0_0_2_2_2_0_0_0_1_1_1_2_2_2
              LONG %%0_0_0_0_0_2_2_2_0_1_1_1_1_1_2_2
              LONG %%0_0_0_0_0_0_2_2_2_1_1_1_1_1_1_2
              LONG %%2_0_0_0_0_0_0_2_2_2_1_1_1_1_1_1
              LONG %%2_2_0_0_0_0_1_1_2_2_2_1_1_1_1_1
              LONG %%2_2_2_0_0_1_1_1_1_2_2_2_1_1_1_1
              LONG %%0_2_2_2_1_1_1_1_1_1_2_2_2_1_1_1
              LONG %%0_0_2_2_2_1_1_1_1_1_1_2_2_2_1_1
              LONG %%0_0_1_2_2_2_1_1_1_1_1_1_2_2_2_1
              LONG %%0_1_1_1_2_2_2_1_1_1_1_1_1_2_2_2
              LONG %%1_1_1_1_1_2_2_2_1_1_1_1_1_1_2_2

' Extracted from file "profi_1px.bmp" at tile=(0, 2), size=(16, 16), palette index=(32)
profi_1px_tx0_ty2_bitmap    LONG
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%0_0_0_0_0_0_0_0_1_1_1_1_1_1_1_1
              LONG %%0_0_0_0_0_0_1_1_1_1_1_1_1_1_1_1
              LONG %%0_0_0_0_0_1_1_1_1_1_1_1_1_1_1_1
              LONG %%0_0_0_0_1_1_1_1_1_1_1_1_1_1_1_1
              LONG %%0_0_0_0_1_1_1_1_1_1_1_1_1_1_1_1
              LONG %%0_0_0_1_1_1_1_1_1_1_1_1_1_1_1_1
              LONG %%0_0_0_1_1_1_1_1_1_1_1_1_1_1_1_1
              LONG %%0_0_0_1_1_1_1_1_1_1_1_1_1_1_1_1
              LONG %%0_0_0_1_1_1_1_1_1_1_1_1_1_1_1_1
              LONG %%0_0_0_1_1_1_1_1_1_1_1_1_1_1_1_1
              LONG %%0_0_0_1_1_1_1_1_1_1_1_1_1_0_0_0
              LONG %%0_0_0_1_1_1_1_1_1_1_1_1_1_0_0_0
              LONG %%0_0_0_1_1_1_1_1_1_1_1_1_1_0_0_0

' Extracted from file "profi_1px.bmp" at tile=(1, 2), size=(16, 16), palette index=(33)
profi_1px_tx1_ty2_bitmap    LONG
              LONG %%1_1_1_1_1_1_2_1_1_1_1_1_1_1_1_0
              LONG %%1_1_1_1_1_1_2_1_1_1_1_1_1_1_0_0
              LONG %%1_1_1_1_1_1_2_1_1_1_1_1_1_0_0_0
              LONG %%1_1_1_1_1_1_0_1_1_1_1_1_0_0_0_0
              LONG %%1_1_1_1_1_1_0_1_1_1_1_0_0_0_0_0
              LONG %%1_1_1_1_1_1_0_0_1_1_0_0_0_0_0_0
              LONG %%1_1_1_1_1_1_0_0_0_0_0_0_0_0_0_0
              LONG %%1_1_1_1_1_1_0_0_0_0_0_0_0_0_0_0
              LONG %%1_1_1_1_1_1_0_0_0_0_0_0_0_0_0_0
              LONG %%1_1_1_1_1_1_0_0_0_0_0_0_0_0_0_0
              LONG %%1_1_1_1_1_1_0_0_0_0_0_0_0_0_0_0
              LONG %%1_1_1_1_1_1_0_0_0_0_0_0_0_0_0_0
              LONG %%1_1_1_1_1_1_0_0_0_0_0_0_0_0_0_0
              LONG %%1_1_1_1_1_1_0_0_0_0_0_0_0_0_0_0
              LONG %%1_1_1_1_1_1_0_0_0_0_0_0_0_0_0_0
              LONG %%1_1_1_1_1_1_0_0_0_0_0_0_0_0_0_0

' Extracted from file "profi_1px.bmp" at tile=(2, 2), size=(16, 16), palette index=(34)
profi_1px_tx2_ty2_bitmap    LONG
              LONG %%0_1_1_1_1_1_1_1_1_2_1_1_1_1_1_1
              LONG %%0_0_1_1_1_1_1_1_1_2_1_1_1_1_1_1
              LONG %%0_0_0_1_1_1_1_1_1_2_1_1_1_1_1_1
              LONG %%0_0_0_0_1_1_1_1_1_2_1_1_1_1_1_1
              LONG %%0_0_0_0_0_1_1_1_1_0_1_1_1_1_1_1
              LONG %%0_0_0_0_0_0_1_1_0_0_1_1_1_1_1_1
              LONG %%0_0_0_0_0_0_0_0_0_0_1_1_1_1_1_1
              LONG %%0_0_0_0_0_0_0_0_0_0_1_1_1_1_1_1
              LONG %%0_0_0_0_0_0_0_0_0_0_1_1_1_1_1_1
              LONG %%0_0_0_0_0_0_0_0_0_0_1_1_1_1_1_1
              LONG %%0_0_0_0_0_0_0_0_0_0_1_1_1_1_1_1
              LONG %%0_0_0_0_0_0_0_0_0_0_1_1_1_1_1_1
              LONG %%0_0_0_0_0_0_0_0_0_0_1_1_1_1_1_1
              LONG %%0_0_0_0_0_0_0_0_0_0_1_1_1_1_1_1
              LONG %%0_0_0_0_0_0_0_0_0_0_1_1_1_1_1_1
              LONG %%0_0_0_0_0_0_0_0_0_0_1_1_1_1_1_1

' Extracted from file "profi_1px.bmp" at tile=(3, 2), size=(16, 16), palette index=(35)
profi_1px_tx3_ty2_bitmap    LONG
              LONG %%1_1_1_1_1_1_1_1_1_1_1_0_0_0_0_0
              LONG %%1_1_1_1_1_1_1_1_1_1_1_0_0_0_0_0
              LONG %%1_1_1_1_1_1_1_1_1_1_1_0_0_0_0_0
              LONG %%1_1_1_1_1_1_1_1_1_1_1_0_0_0_0_0
              LONG %%1_1_1_1_1_1_1_1_1_1_1_0_0_0_0_0
              LONG %%1_1_1_1_1_1_1_1_1_1_1_0_0_0_0_0
              LONG %%1_1_1_1_1_1_1_1_1_1_1_0_0_0_0_0
              LONG %%1_1_1_1_1_1_1_1_1_1_1_0_0_0_0_0
              LONG %%1_1_1_1_1_1_1_1_1_1_1_0_0_0_0_0
              LONG %%1_1_1_1_1_1_1_1_1_1_1_0_0_0_0_0
              LONG %%1_1_1_1_1_1_1_1_1_1_1_0_0_0_0_0
              LONG %%1_1_1_1_1_1_1_1_1_1_1_0_0_0_0_0
              LONG %%1_1_1_1_1_1_1_1_1_1_0_0_0_0_0_0
              LONG %%1_1_1_1_1_1_1_1_1_1_0_0_0_0_0_0
              LONG %%1_1_1_1_1_1_1_1_1_0_0_0_0_0_0_0
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0

' Extracted from file "profi_1px.bmp" at tile=(4, 2), size=(16, 16), palette index=(36)
profi_1px_tx4_ty2_bitmap    LONG
              LONG %%0_0_0_0_0_1_1_1_1_1_1_1_1_1_1_1
              LONG %%0_0_0_0_0_1_1_1_1_1_1_1_1_1_1_1
              LONG %%0_0_0_0_0_1_1_1_1_1_1_1_1_1_1_1
              LONG %%0_0_0_0_0_1_1_1_1_1_1_1_1_1_1_1
              LONG %%0_0_0_0_0_1_1_1_1_1_1_1_1_1_1_1
              LONG %%0_0_0_0_0_1_1_1_1_1_1_1_1_1_1_1
              LONG %%0_0_0_0_0_1_1_1_1_1_1_1_1_1_1_1
              LONG %%0_0_0_0_0_1_1_1_1_1_1_1_1_1_1_1
              LONG %%0_0_0_0_0_1_1_1_1_1_1_1_1_1_1_1
              LONG %%0_0_0_0_0_1_1_1_1_1_1_1_1_1_1_1
              LONG %%0_0_0_0_0_1_1_1_1_1_1_1_1_1_1_1
              LONG %%0_0_0_0_0_1_1_1_1_1_1_1_1_1_1_1
              LONG %%0_0_0_0_0_0_1_1_1_1_1_1_1_1_1_1
              LONG %%0_0_0_0_0_0_1_1_1_1_1_1_1_1_1_1
              LONG %%0_0_0_0_0_0_0_1_1_1_1_1_1_1_1_1
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0

' Extracted from file "profi_1px.bmp" at tile=(5, 2), size=(16, 16), palette index=(37)
profi_1px_tx5_ty2_bitmap    LONG
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%1_1_1_1_1_1_0_0_0_0_0_0_0_0_0_0
              LONG %%1_1_1_1_1_1_0_0_0_0_0_0_0_0_0_0
              LONG %%1_1_1_1_1_1_0_0_0_0_0_0_0_0_0_0
              LONG %%2_2_2_2_2_2_1_1_1_1_1_1_1_1_0_0
              LONG %%1_1_1_1_1_1_1_1_1_1_1_1_1_1_1_0
              LONG %%1_1_1_1_1_1_1_1_1_1_1_1_1_1_1_0
              LONG %%1_1_1_1_1_1_1_1_1_1_1_1_1_1_1_0
              LONG %%1_1_1_1_1_1_1_1_1_1_1_1_1_1_0_0
              LONG %%1_1_1_1_1_1_1_1_1_1_1_0_0_0_0_0
              LONG %%1_1_1_1_1_0_0_0_0_0_0_0_0_0_0_0
              LONG %%2_2_2_2_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%2_2_2_2_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%2_2_2_2_2_0_0_0_0_0_0_0_0_0_0_0
              LONG %%2_2_2_2_2_0_0_0_0_0_0_0_0_0_0_0
              LONG %%2_2_2_2_2_2_0_0_0_0_0_0_0_0_0_0

' Extracted from file "profi_1px.bmp" at tile=(6, 2), size=(16, 16), palette index=(38)
profi_1px_tx6_ty2_bitmap    LONG
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%0_0_0_0_0_0_0_0_0_0_1_1_1_1_1_1
              LONG %%0_0_0_0_0_0_0_0_0_0_1_1_1_1_1_1
              LONG %%0_0_0_0_0_0_0_0_0_0_1_1_1_1_1_1
              LONG %%1_1_1_1_1_1_1_1_1_1_2_2_2_2_2_2
              LONG %%1_1_1_1_1_1_1_1_1_1_1_1_1_1_1_1
              LONG %%1_1_1_1_1_1_1_1_1_1_1_1_1_1_1_1
              LONG %%1_1_1_1_1_1_1_1_1_1_1_1_1_1_1_1
              LONG %%1_1_1_1_1_1_1_1_1_1_1_1_1_1_1_1
              LONG %%1_1_1_1_1_1_1_1_1_1_1_1_1_1_1_1
              LONG %%1_1_1_1_1_1_1_1_1_1_1_1_1_1_1_1
              LONG %%1_1_1_1_1_1_1_1_1_1_1_1_1_1_1_2
              LONG %%1_1_1_1_1_1_1_1_0_0_0_2_2_2_2_2
              LONG %%0_0_0_0_0_0_0_0_0_0_2_2_2_2_2_2
              LONG %%0_0_0_0_0_0_0_0_0_0_2_2_2_2_2_2
              LONG %%0_0_0_0_0_0_0_0_0_2_2_2_2_2_2_2

' Extracted from file "profi_1px.bmp" at tile=(7, 2), size=(16, 16), palette index=(39)
profi_1px_tx7_ty2_bitmap    LONG
              LONG %%2_2_2_2_2_2_2_0_0_0_0_0_0_0_0_0
              LONG %%2_2_2_2_2_2_2_0_0_0_0_0_0_0_0_0
              LONG %%2_2_2_2_2_2_0_0_0_0_0_0_0_0_0_0
              LONG %%2_2_2_2_2_2_0_0_0_0_0_0_0_0_0_0
              LONG %%2_2_2_2_2_0_0_0_0_0_0_0_0_0_0_0
              LONG %%2_2_2_2_2_0_0_0_0_0_0_0_0_0_0_0
              LONG %%1_1_1_1_1_0_0_0_0_0_0_0_0_0_0_0
              LONG %%1_1_1_1_1_1_1_1_1_1_1_0_0_0_0_0
              LONG %%1_1_1_1_1_1_1_1_1_1_1_1_1_1_0_0
              LONG %%1_1_1_1_1_1_1_1_1_1_1_1_1_1_1_0
              LONG %%1_1_1_1_1_1_1_1_1_1_1_1_1_1_1_0
              LONG %%1_1_1_1_1_1_1_1_1_1_1_1_1_1_1_0
              LONG %%1_1_1_1_1_1_1_1_1_1_1_1_1_1_0_0
              LONG %%1_1_1_1_1_1_0_0_0_0_0_0_0_0_0_0
              LONG %%1_1_1_1_1_1_0_0_0_0_0_0_0_0_0_0
              LONG %%3_3_3_3_3_3_0_0_0_0_0_0_0_0_0_0

' Extracted from file "profi_1px.bmp" at tile=(8, 2), size=(16, 16), palette index=(40)
profi_1px_tx8_ty2_bitmap    LONG
              LONG %%0_0_0_0_0_0_0_0_0_0_2_2_2_2_2_2
              LONG %%0_0_0_0_0_0_0_0_0_0_2_2_2_2_2_2
              LONG %%0_0_0_0_0_0_0_0_0_0_0_2_2_2_2_2
              LONG %%0_0_0_0_0_0_0_0_0_0_0_2_2_2_2_2
              LONG %%1_1_1_1_1_1_1_1_0_0_0_0_2_2_2_2
              LONG %%1_1_1_1_1_1_1_1_1_1_1_1_1_1_2_2
              LONG %%1_1_1_1_1_1_1_1_1_1_1_1_1_1_1_1
              LONG %%1_1_1_1_1_1_1_1_1_1_1_1_1_1_1_1
              LONG %%1_1_1_1_1_1_1_1_1_1_1_1_1_1_1_1
              LONG %%1_1_1_1_1_1_1_1_1_1_1_1_1_1_1_1
              LONG %%1_1_1_1_1_1_1_1_1_1_1_1_1_1_1_1
              LONG %%1_1_1_1_1_1_1_1_1_1_1_1_1_1_1_1
              LONG %%1_1_1_1_1_1_1_1_1_1_1_1_1_1_1_1
              LONG %%0_0_0_0_0_0_0_0_0_0_1_1_1_1_1_1
              LONG %%0_0_0_0_0_0_0_0_0_0_1_1_1_1_1_1
              LONG %%0_0_0_0_0_0_0_0_0_0_3_3_3_3_3_3

' Extracted from file "profi_1px.bmp" at tile=(9, 2), size=(16, 16), palette index=(41)
profi_1px_tx9_ty2_bitmap    LONG
              LONG %%1_1_0_0_0_0_0_0_1_1_1_0_0_0_0_0
              LONG %%1_1_1_2_2_2_0_0_0_1_1_1_0_0_0_0
              LONG %%2_1_1_1_2_2_0_0_0_0_1_1_1_0_0_0
              LONG %%2_2_1_1_1_2_0_0_0_0_0_1_1_1_0_0
              LONG %%2_2_2_1_1_1_2_2_2_2_2_2_1_1_1_0
              LONG %%2_2_2_2_1_1_1_2_2_2_2_2_2_1_1_1
              LONG %%2_2_2_2_2_1_1_1_2_2_2_2_2_2_1_1
              LONG %%2_2_2_2_2_2_1_1_1_2_2_2_2_2_3_1
              LONG %%1_2_2_2_2_2_2_1_1_1_2_2_2_2_0_0
              LONG %%1_1_2_2_2_2_2_2_1_1_1_0_0_0_0_0
              LONG %%1_1_1_2_2_0_0_0_0_1_1_1_0_0_0_0
              LONG %%3_1_1_1_0_0_0_0_0_0_1_1_1_0_0_0
              LONG %%3_3_1_1_1_0_0_0_0_0_0_1_1_1_0_0
              LONG %%3_3_3_1_1_1_0_0_0_0_0_0_1_1_1_0
              LONG %%3_3_3_3_1_1_1_0_0_0_0_0_0_1_1_1
              LONG %%3_3_3_3_3_1_1_1_0_0_0_0_0_0_1_1

' Extracted from file "profi_1px.bmp" at tile=(10, 2), size=(16, 16), palette index=(42)
profi_1px_tx10_ty2_bitmap    LONG
              LONG %%2_2_0_0_0_0_0_0_2_2_2_0_0_0_0_0
              LONG %%2_2_2_0_0_0_0_0_0_2_2_2_1_1_1_1
              LONG %%0_2_2_2_0_0_0_0_0_0_2_2_2_1_1_1
              LONG %%0_0_2_2_2_0_0_0_0_0_1_2_2_2_1_1
              LONG %%1_1_1_2_2_2_1_1_1_1_1_1_2_2_2_1
              LONG %%1_1_1_1_2_2_2_1_1_1_1_1_1_2_2_2
              LONG %%1_1_1_1_1_2_2_2_1_1_1_1_1_1_2_2
              LONG %%1_1_1_1_1_1_2_2_2_1_1_1_1_1_1_2
              LONG %%2_1_1_1_1_1_1_2_2_2_1_1_1_1_1_1
              LONG %%2_2_1_1_1_1_1_1_2_2_2_1_1_1_1_1
              LONG %%2_2_2_1_1_1_1_1_1_2_2_2_1_1_1_1
              LONG %%1_2_2_2_1_1_1_1_1_1_2_2_2_1_1_3
              LONG %%1_1_2_2_2_1_1_1_0_0_0_2_2_2_3_3
              LONG %%0_0_0_2_2_2_0_0_0_0_3_3_2_2_2_3
              LONG %%0_0_0_0_2_2_2_0_0_0_3_3_3_2_2_2
              LONG %%0_0_0_0_0_2_2_2_0_3_3_3_3_3_2_2

' Extracted from file "profi_1px.bmp" at tile=(11, 2), size=(16, 16), palette index=(43)
profi_1px_tx11_ty2_bitmap    LONG
              LONG %%2_2_0_0_0_0_0_0_2_2_2_0_0_0_0_0
              LONG %%2_2_2_1_1_1_0_0_0_2_2_2_0_0_0_0
              LONG %%1_2_2_2_1_1_0_0_0_0_2_2_2_0_0_0
              LONG %%1_1_2_2_2_1_0_0_0_0_0_2_2_2_0_0
              LONG %%1_1_1_2_2_2_1_1_1_1_1_1_2_2_2_1
              LONG %%1_1_1_1_2_2_2_1_1_1_1_1_1_2_2_2
              LONG %%1_1_1_1_1_2_2_2_1_1_1_1_1_1_2_2
              LONG %%1_1_1_1_1_1_2_2_2_1_1_1_1_1_1_2
              LONG %%2_1_1_1_1_1_1_2_2_2_1_1_1_1_1_1
              LONG %%2_2_1_1_1_1_1_1_2_2_2_1_1_1_1_1
              LONG %%2_2_2_1_1_1_1_1_1_2_2_2_1_1_1_1
              LONG %%3_2_2_2_1_1_1_1_1_1_2_2_2_1_1_1
              LONG %%3_3_2_2_2_0_0_0_1_1_1_2_2_2_1_1
              LONG %%3_3_3_2_2_2_0_0_0_0_0_0_2_2_2_0
              LONG %%3_3_3_3_2_2_2_0_0_0_0_0_0_2_2_2
              LONG %%3_3_3_3_3_2_2_2_0_0_0_0_0_0_2_2

' Extracted from file "profi_1px.bmp" at tile=(12, 2), size=(16, 16), palette index=(44)
profi_1px_tx12_ty2_bitmap    LONG
              LONG %%1_1_0_0_0_0_0_0_1_1_1_0_0_0_0_0
              LONG %%1_1_1_0_0_0_0_0_0_1_1_1_2_2_2_2
              LONG %%0_1_1_1_0_0_0_0_0_0_1_1_1_2_2_2
              LONG %%0_0_1_1_1_0_0_0_0_0_2_1_1_1_2_2
              LONG %%0_0_2_1_1_1_2_2_2_2_2_2_1_1_1_2
              LONG %%0_2_2_2_1_1_1_2_2_2_2_2_2_1_1_1
              LONG %%0_2_2_2_2_1_1_1_2_2_2_2_2_2_1_1
              LONG %%0_2_2_2_2_2_1_1_1_2_2_2_2_2_2_1
              LONG %%1_0_2_2_2_2_2_1_1_1_2_2_2_2_2_2
              LONG %%1_1_0_0_0_2_2_2_1_1_1_2_2_2_2_2
              LONG %%1_1_1_0_0_0_0_0_0_1_1_1_2_2_2_2
              LONG %%0_1_1_1_0_0_0_0_0_0_1_1_1_3_3_3
              LONG %%0_0_1_1_1_0_0_0_0_0_0_1_1_1_3_3
              LONG %%0_0_0_1_1_1_0_0_0_0_0_3_1_1_1_3
              LONG %%0_0_0_0_1_1_1_0_0_0_0_3_3_1_1_1
              LONG %%0_0_0_0_0_1_1_1_0_0_3_3_3_3_1_1

' Extracted from file "profi_1px.bmp" at tile=(13, 2), size=(16, 16), palette index=(45)
profi_1px_tx13_ty2_bitmap    LONG
              LONG %%2_2_0_0_0_0_0_0_2_2_2_0_0_0_0_0
              LONG %%2_2_2_0_0_0_0_0_0_2_2_2_0_0_0_0
              LONG %%0_2_2_2_0_0_0_0_0_0_2_2_2_0_0_0
              LONG %%1_1_2_2_2_1_1_1_0_0_0_2_2_2_0_0
              LONG %%1_1_1_2_2_2_1_1_1_1_0_0_2_2_2_0
              LONG %%1_1_1_1_2_2_2_1_1_1_1_0_0_2_2_2
              LONG %%1_1_1_1_1_2_2_2_1_1_1_1_0_0_2_2
              LONG %%1_1_1_1_1_1_2_2_2_1_1_1_0_0_0_2
              LONG %%2_1_1_1_1_1_1_2_2_2_1_1_1_0_0_0
              LONG %%2_2_1_1_1_1_1_1_2_2_2_1_1_0_0_0
              LONG %%2_2_2_1_1_1_1_1_1_2_2_2_1_0_0_0
              LONG %%1_2_2_2_1_1_1_1_1_1_2_2_2_0_0_0
              LONG %%1_1_2_2_2_1_1_1_1_1_1_2_2_2_0_0
              LONG %%0_0_0_2_2_2_1_1_1_1_1_1_2_2_2_0
              LONG %%0_0_0_1_2_2_2_1_1_1_1_1_1_2_2_2
              LONG %%0_0_0_1_1_2_2_2_1_1_1_1_1_0_2_2

' Extracted from file "profi_1px.bmp" at tile=(14, 2), size=(16, 16), palette index=(46)
profi_1px_tx14_ty2_bitmap    LONG
              LONG %%1_1_2_2_2_2_2_2_1_1_1_2_2_2_2_0
              LONG %%1_1_1_2_2_2_2_2_2_1_1_1_2_2_0_0
              LONG %%2_1_1_1_2_2_2_2_2_2_1_1_1_0_0_0
              LONG %%2_2_1_1_1_2_2_2_2_2_2_1_1_1_0_0
              LONG %%2_2_2_1_1_1_0_2_2_2_2_0_1_1_1_0
              LONG %%2_2_2_2_1_1_1_0_2_2_0_0_0_1_1_1
              LONG %%2_2_2_2_2_1_1_1_0_0_0_0_0_0_1_1
              LONG %%2_2_2_2_2_2_1_1_1_0_0_0_0_0_0_1
              LONG %%1_2_2_2_2_2_0_1_1_1_0_0_0_0_0_0
              LONG %%1_1_2_2_2_2_0_0_1_1_1_0_0_0_0_0
              LONG %%1_1_1_2_2_2_0_0_0_1_1_1_0_0_0_0
              LONG %%2_1_1_1_2_2_0_0_0_0_1_1_1_0_0_0
              LONG %%2_2_1_1_1_2_0_0_0_0_0_1_1_1_0_0
              LONG %%2_2_2_1_1_1_0_0_0_0_0_0_1_1_1_0
              LONG %%2_2_2_2_1_1_1_0_0_0_0_0_0_1_1_1
              LONG %%2_2_2_2_2_1_1_1_0_0_0_0_0_0_1_1

' Extracted from file "profi_1px.bmp" at tile=(15, 2), size=(16, 16), palette index=(47)
profi_1px_tx15_ty2_bitmap    LONG
              LONG %%2_2_1_1_1_1_1_1_2_2_2_1_1_1_1_1
              LONG %%2_2_2_1_1_1_1_1_1_2_2_2_1_1_1_1
              LONG %%0_2_2_2_1_1_1_1_1_1_2_2_2_1_1_1
              LONG %%0_0_2_2_2_1_1_1_1_1_1_2_2_2_1_1
              LONG %%0_0_0_2_2_2_1_1_1_0_1_1_2_2_2_1
              LONG %%0_0_0_0_2_2_2_1_0_0_1_1_1_2_2_2
              LONG %%0_0_0_0_0_2_2_2_0_0_1_1_1_1_2_2
              LONG %%0_0_0_0_0_0_2_2_2_0_1_1_1_1_1_2
              LONG %%2_0_0_0_0_0_0_2_2_2_1_1_1_1_1_1
              LONG %%2_2_0_0_0_0_0_0_2_2_2_1_1_1_1_1
              LONG %%2_2_2_0_0_0_0_0_0_2_2_2_1_1_1_1
              LONG %%0_2_2_2_0_0_0_0_0_0_2_2_2_1_1_1
              LONG %%0_0_2_2_2_0_0_0_0_0_1_2_2_2_1_1
              LONG %%0_0_0_2_2_2_0_0_0_0_1_1_2_2_2_1
              LONG %%0_0_0_0_2_2_2_0_0_0_1_1_1_2_2_2
              LONG %%0_0_0_0_0_2_2_2_0_0_1_1_1_1_2_2

' Extracted from file "profi_1px.bmp" at tile=(0, 3), size=(16, 16), palette index=(48)
profi_1px_tx0_ty3_bitmap    LONG
              LONG %%0_0_0_1_1_1_1_1_1_1_1_1_1_0_0_0
              LONG %%0_0_0_1_1_1_1_1_1_1_1_1_1_0_0_0
              LONG %%0_0_0_1_1_1_1_1_1_1_1_1_1_0_0_0
              LONG %%0_0_0_1_1_1_1_1_1_1_1_1_1_0_0_0
              LONG %%0_0_0_1_1_1_1_1_1_1_1_1_1_0_0_0
              LONG %%0_0_0_1_1_1_1_1_1_1_1_1_1_0_0_0
              LONG %%0_0_0_1_1_1_1_1_1_1_1_1_1_0_0_0
              LONG %%0_0_0_1_1_1_1_1_1_1_1_1_1_0_0_0
              LONG %%0_0_0_1_1_1_1_1_1_1_1_1_1_0_0_0
              LONG %%0_0_0_1_1_1_1_1_1_1_1_1_1_0_0_0
              LONG %%0_0_0_1_1_1_1_1_1_1_1_1_1_0_0_0
              LONG %%0_0_0_1_1_1_1_1_1_1_1_1_1_0_0_0
              LONG %%0_0_0_1_1_1_1_1_1_1_1_1_1_0_0_0
              LONG %%0_0_0_1_1_1_1_1_1_1_1_1_1_0_0_0
              LONG %%0_0_0_1_1_1_1_1_1_1_1_1_1_0_0_0
              LONG %%0_0_0_1_1_1_1_1_1_1_1_1_1_0_0_0

' Extracted from file "profi_1px.bmp" at tile=(1, 3), size=(16, 16), palette index=(49)
profi_1px_tx1_ty3_bitmap    LONG
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%1_1_1_0_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%1_1_1_1_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%1_1_1_1_1_0_0_0_0_0_0_0_0_0_0_0
              LONG %%1_1_1_1_1_1_0_0_0_0_0_0_0_0_0_0
              LONG %%1_1_1_1_1_1_1_0_0_0_0_0_0_0_0_0
              LONG %%1_1_1_1_1_1_1_1_0_0_0_0_0_0_0_0

' Extracted from file "profi_1px.bmp" at tile=(2, 3), size=(16, 16), palette index=(50)
profi_1px_tx2_ty3_bitmap    LONG
              LONG %%1_1_1_1_1_1_0_0_0_0_0_0_0_0_0_0
              LONG %%1_1_1_1_1_1_0_0_0_0_0_0_0_0_0_0
              LONG %%1_1_1_1_1_1_1_1_0_0_0_0_0_0_0_0
              LONG %%1_1_1_1_1_1_1_1_1_0_0_0_0_0_0_0
              LONG %%1_1_1_1_1_1_1_1_1_0_0_0_0_0_0_0
              LONG %%1_1_1_1_1_1_1_1_1_0_0_0_0_0_0_0
              LONG %%1_1_1_1_1_1_1_1_2_0_0_0_0_0_0_0
              LONG %%1_1_1_1_1_1_1_2_1_1_0_0_0_0_0_0
              LONG %%1_1_1_1_1_1_2_1_1_1_1_0_0_0_0_0
              LONG %%1_1_1_1_1_2_1_1_1_1_1_1_0_0_0_0
              LONG %%1_1_1_1_1_0_1_1_1_1_1_1_1_0_0_2
              LONG %%1_1_1_1_0_0_0_1_1_1_1_1_1_1_2_2
              LONG %%1_1_1_0_0_0_0_0_1_1_1_1_1_2_2_2
              LONG %%1_1_0_0_0_0_0_0_0_1_1_1_2_2_2_2
              LONG %%0_0_0_0_0_0_0_0_0_0_1_2_2_2_2_2
              LONG %%0_0_0_0_0_0_0_0_0_2_2_2_2_2_2_2

' Extracted from file "profi_1px.bmp" at tile=(3, 3), size=(16, 16), palette index=(51)
profi_1px_tx3_ty3_bitmap    LONG
              LONG %%0_0_0_0_0_0_0_0_0_0_1_1_1_1_1_1
              LONG %%0_0_0_0_0_0_0_0_0_0_1_1_1_1_1_1
              LONG %%0_0_0_0_0_0_0_0_1_1_1_1_1_1_1_1
              LONG %%0_0_0_0_0_0_0_1_1_1_1_1_1_1_1_1
              LONG %%0_0_0_0_0_0_0_1_1_1_1_1_1_1_1_1
              LONG %%0_0_0_0_0_0_0_1_1_1_1_1_1_1_1_1
              LONG %%0_0_0_0_0_0_0_2_1_1_1_1_1_1_1_1
              LONG %%0_0_0_0_0_0_1_1_2_1_1_1_1_1_1_1
              LONG %%0_0_0_0_0_1_1_1_1_2_1_1_1_1_1_1
              LONG %%0_0_0_0_1_1_1_1_1_1_2_1_1_1_1_1
              LONG %%2_0_0_1_1_1_1_1_1_1_0_1_1_1_1_1
              LONG %%2_2_1_1_1_1_1_1_1_0_0_0_1_1_1_1
              LONG %%2_2_2_1_1_1_1_1_0_0_0_0_0_1_1_1
              LONG %%2_2_2_2_1_1_1_0_0_0_0_0_0_0_1_1
              LONG %%2_2_2_2_2_1_0_0_0_0_0_0_0_0_0_0
              LONG %%2_2_2_2_2_2_2_0_0_0_0_0_0_0_0_0

' Extracted from file "profi_1px.bmp" at tile=(4, 3), size=(16, 16), palette index=(52)
profi_1px_tx4_ty3_bitmap    LONG
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_1_1_1
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_1_1_1_1
              LONG %%0_0_0_0_0_0_0_0_0_0_0_1_1_1_1_1
              LONG %%0_0_0_0_0_0_0_0_0_0_1_1_1_1_1_1
              LONG %%0_0_0_0_0_0_0_0_0_1_1_1_1_1_1_1
              LONG %%0_0_0_0_0_0_0_0_1_1_1_1_1_1_1_1

' Extracted from file "profi_1px.bmp" at tile=(5, 3), size=(16, 16), palette index=(53)
profi_1px_tx5_ty3_bitmap    LONG
              LONG %%2_2_2_2_2_2_0_0_0_0_0_0_0_0_0_0
              LONG %%2_2_2_2_2_2_0_0_0_0_0_0_0_0_0_0
              LONG %%2_2_2_2_2_0_0_0_0_0_0_0_0_0_0_0
              LONG %%2_2_2_2_2_0_0_0_0_0_0_0_0_0_0_0
              LONG %%2_2_2_2_0_0_0_0_1_1_1_1_1_1_1_1
              LONG %%2_2_1_1_1_1_1_1_1_1_1_1_1_1_1_1
              LONG %%1_1_1_1_1_1_1_1_1_1_1_1_1_1_1_1
              LONG %%1_1_1_1_1_1_1_1_1_1_1_1_1_1_1_1
              LONG %%1_1_1_1_1_1_1_1_1_1_1_1_1_1_1_1
              LONG %%1_1_1_1_1_1_1_1_1_1_1_1_1_1_1_1
              LONG %%1_1_1_1_1_1_1_1_1_1_1_1_1_1_1_1
              LONG %%1_1_1_1_1_1_1_1_1_1_1_1_1_1_1_1
              LONG %%1_1_1_1_1_1_1_1_1_1_1_1_1_1_1_1
              LONG %%1_1_1_1_1_1_0_0_0_0_0_0_0_0_0_0
              LONG %%1_1_1_1_1_1_0_0_0_0_0_0_0_0_0_0
              LONG %%3_3_3_3_3_3_0_0_0_0_0_0_0_0_0_0

' Extracted from file "profi_1px.bmp" at tile=(6, 3), size=(16, 16), palette index=(54)
profi_1px_tx6_ty3_bitmap    LONG
              LONG %%0_0_0_0_0_0_0_0_0_2_2_2_2_2_2_2
              LONG %%0_0_0_0_0_0_0_0_0_2_2_2_2_2_2_2
              LONG %%0_0_0_0_0_0_0_0_0_0_2_2_2_2_2_2
              LONG %%0_0_0_0_0_0_0_0_0_0_2_2_2_2_2_2
              LONG %%0_0_0_0_0_0_0_0_0_0_0_2_2_2_2_2
              LONG %%0_0_0_0_0_0_0_0_0_0_0_2_2_2_2_2
              LONG %%0_0_0_0_0_0_0_0_0_0_0_1_1_1_1_1
              LONG %%0_0_0_0_0_1_1_1_1_1_1_1_1_1_1_1
              LONG %%0_0_1_1_1_1_1_1_1_1_1_1_1_1_1_1
              LONG %%0_1_1_1_1_1_1_1_1_1_1_1_1_1_1_1
              LONG %%0_1_1_1_1_1_1_1_1_1_1_1_1_1_1_1
              LONG %%0_1_1_1_1_1_1_1_1_1_1_1_1_1_1_1
              LONG %%0_0_1_1_1_1_1_1_1_1_1_1_1_1_1_1
              LONG %%0_0_0_0_0_0_0_0_0_0_1_1_1_1_1_1
              LONG %%0_0_0_0_0_0_0_0_0_0_1_1_1_1_1_1
              LONG %%0_0_0_0_0_0_0_0_0_0_3_3_3_3_3_3

' Extracted from file "profi_1px.bmp" at tile=(7, 3), size=(16, 16), palette index=(55)
profi_1px_tx7_ty3_bitmap    LONG
              LONG %%2_2_0_0_0_0_0_0_2_2_2_0_0_0_0_0
              LONG %%2_2_2_0_0_0_0_0_0_2_2_2_0_0_0_0
              LONG %%0_2_2_2_0_0_0_0_0_0_2_2_2_0_0_0
              LONG %%1_1_2_2_2_1_1_1_1_1_1_2_2_2_1_1
              LONG %%1_1_1_2_2_2_1_1_1_1_1_1_2_2_2_1
              LONG %%1_1_1_1_2_2_2_1_1_1_1_1_1_2_2_2
              LONG %%1_1_1_1_1_2_2_2_1_1_1_1_1_1_2_2
              LONG %%1_1_1_1_1_1_2_2_2_1_1_1_1_1_1_2
              LONG %%2_1_1_1_1_1_1_2_2_2_1_1_1_1_1_1
              LONG %%2_2_1_1_1_1_1_1_2_2_2_1_1_1_1_1
              LONG %%2_2_2_1_1_1_1_1_1_2_2_2_1_1_1_1
              LONG %%1_2_2_2_1_1_1_1_1_1_2_2_2_1_1_1
              LONG %%1_1_2_2_2_1_1_1_1_1_1_2_2_2_1_1
              LONG %%0_0_0_2_2_2_0_0_0_0_0_0_2_2_2_0
              LONG %%0_0_0_0_2_2_2_0_0_0_0_0_0_2_2_2
              LONG %%0_0_0_0_0_2_2_2_0_0_0_0_0_0_2_2

' Extracted from file "profi_1px.bmp" at tile=(8, 3), size=(16, 16), palette index=(56)
profi_1px_tx8_ty3_bitmap    LONG
              LONG %%2_2_3_3_3_3_3_3_2_2_2_0_0_0_0_0
              LONG %%2_2_2_1_1_1_1_1_1_2_2_2_0_0_0_0
              LONG %%1_2_2_2_1_1_1_1_1_1_2_2_2_3_3_0
              LONG %%1_1_2_2_2_1_1_1_1_1_1_2_2_2_1_3
              LONG %%1_1_1_2_2_2_1_1_1_1_1_1_2_2_2_1
              LONG %%1_1_1_1_2_2_2_1_1_1_1_1_1_2_2_2
              LONG %%1_1_1_1_1_2_2_2_1_1_1_1_1_1_2_2
              LONG %%1_1_1_1_1_1_2_2_2_1_1_1_1_1_1_2
              LONG %%2_1_1_1_1_1_1_2_2_2_1_1_1_1_1_1
              LONG %%2_2_1_1_1_1_1_1_2_2_2_1_1_1_1_1
              LONG %%2_2_2_1_1_1_1_1_1_2_2_2_1_1_1_1
              LONG %%1_2_2_2_1_1_1_1_1_1_2_2_2_1_1_1
              LONG %%1_1_2_2_2_1_1_1_1_1_1_2_2_2_1_3
              LONG %%1_1_1_2_2_2_1_1_1_1_1_1_2_2_2_0
              LONG %%1_1_1_1_2_2_2_1_1_3_3_3_0_2_2_2
              LONG %%3_3_3_3_3_2_2_2_3_0_0_0_0_0_2_2

' Extracted from file "profi_1px.bmp" at tile=(9, 3), size=(16, 16), palette index=(57)
profi_1px_tx9_ty3_bitmap    LONG
              LONG %%2_2_3_3_3_3_0_0_2_2_2_0_0_0_0_0
              LONG %%2_2_2_3_3_3_0_0_0_2_2_2_0_0_0_0
              LONG %%3_2_2_2_3_0_0_0_0_0_2_2_2_0_0_0
              LONG %%3_3_2_2_2_0_0_0_0_0_0_2_2_2_0_0
              LONG %%3_3_3_2_2_2_0_0_1_1_1_1_2_2_2_1
              LONG %%3_3_1_1_2_2_2_1_1_1_1_1_1_2_2_2
              LONG %%1_1_1_1_1_2_2_2_1_1_1_1_1_1_2_2
              LONG %%1_1_1_1_1_1_2_2_2_1_1_1_1_1_1_2
              LONG %%2_1_1_1_1_1_1_2_2_2_1_1_1_1_1_1
              LONG %%2_2_1_1_1_1_1_1_2_2_2_1_1_1_1_1
              LONG %%2_2_2_1_1_1_1_1_1_2_2_2_1_1_1_1
              LONG %%1_2_2_2_1_1_1_1_1_1_2_2_2_1_1_1
              LONG %%1_1_2_2_2_1_1_1_1_1_1_2_2_2_1_1
              LONG %%1_1_1_2_2_2_0_0_0_0_0_0_2_2_2_0
              LONG %%1_1_1_1_2_2_2_0_0_0_0_0_0_2_2_2
              LONG %%1_1_1_1_1_2_2_2_0_0_0_0_0_0_2_2

' Extracted from file "profi_1px.bmp" at tile=(10, 3), size=(16, 16), palette index=(58)
profi_1px_tx10_ty3_bitmap    LONG
              LONG %%1_1_0_0_0_0_0_0_1_1_1_3_3_3_3_3
              LONG %%1_1_1_0_0_0_0_0_0_1_1_1_3_3_3_3
              LONG %%0_1_1_1_0_0_0_0_0_0_1_1_1_3_3_3
              LONG %%0_0_1_1_1_0_0_0_0_0_3_1_1_1_3_3
              LONG %%0_0_0_1_1_1_0_0_0_0_0_3_1_1_1_3
              LONG %%0_0_0_0_1_1_1_0_0_0_0_3_3_1_1_1
              LONG %%0_0_0_0_0_1_1_1_0_0_0_2_2_2_1_1
              LONG %%0_0_0_0_0_2_1_1_1_2_2_2_2_2_2_1
              LONG %%1_0_2_2_2_2_2_1_1_1_2_2_2_2_2_2
              LONG %%1_1_2_2_2_2_2_2_1_1_1_2_2_2_2_2
              LONG %%1_1_1_2_2_2_2_2_2_1_1_1_2_2_2_2
              LONG %%0_1_1_1_2_2_2_2_2_2_1_1_1_2_2_2
              LONG %%0_0_1_1_1_2_2_2_2_2_2_1_1_1_2_2
              LONG %%0_0_0_1_1_1_0_0_0_0_2_2_1_1_1_2
              LONG %%0_0_0_0_1_1_1_0_0_0_2_2_2_1_1_1
              LONG %%0_0_0_0_0_1_1_1_0_0_2_2_2_2_1_1

' Extracted from file "profi_1px.bmp" at tile=(11, 3), size=(16, 16), palette index=(59)
profi_1px_tx11_ty3_bitmap    LONG
              LONG %%1_1_3_3_3_3_3_0_1_1_1_0_0_0_0_0
              LONG %%1_1_1_3_3_3_3_0_0_1_1_1_0_0_0_0
              LONG %%3_1_1_1_3_3_0_0_0_0_1_1_1_0_0_0
              LONG %%3_3_1_1_1_3_0_0_0_0_0_1_1_1_0_0
              LONG %%3_3_3_1_1_1_0_0_0_0_0_0_1_1_1_0
              LONG %%3_3_3_3_1_1_1_0_0_0_0_0_0_1_1_1
              LONG %%2_2_2_2_2_1_1_1_0_0_0_0_0_0_1_1
              LONG %%2_2_2_2_2_2_1_1_1_2_2_0_0_0_0_1
              LONG %%1_2_2_2_2_2_2_1_1_1_2_2_2_2_0_0
              LONG %%1_1_2_2_2_2_2_2_1_1_1_2_2_2_2_0
              LONG %%1_1_1_2_2_2_2_2_2_1_1_1_2_2_2_0
              LONG %%2_1_1_1_2_2_2_2_2_2_1_1_1_2_2_0
              LONG %%2_2_1_1_1_2_2_2_2_2_2_1_1_1_0_0
              LONG %%2_2_2_1_1_1_0_0_0_0_0_0_1_1_1_0
              LONG %%2_2_2_2_1_1_1_0_0_0_0_0_0_1_1_1
              LONG %%2_2_2_2_2_1_1_1_0_0_0_0_0_0_1_1

' Extracted from file "profi_1px.bmp" at tile=(12, 3), size=(16, 16), palette index=(60)
profi_1px_tx12_ty3_bitmap    LONG
              LONG %%2_2_0_0_0_0_0_0_2_2_2_3_3_3_3_3
              LONG %%2_2_2_0_0_0_0_0_0_2_2_2_3_3_3_3
              LONG %%0_2_2_2_0_0_0_0_0_0_2_2_2_3_3_3
              LONG %%0_0_2_2_2_0_0_0_0_0_0_2_2_2_3_3
              LONG %%1_1_1_2_2_2_1_1_0_0_0_0_2_2_2_3
              LONG %%1_1_1_1_2_2_2_1_1_1_1_1_1_2_2_2
              LONG %%1_1_1_1_1_2_2_2_1_1_1_1_1_1_2_2
              LONG %%1_1_1_1_1_1_2_2_2_1_1_1_1_1_1_2
              LONG %%2_1_1_1_1_1_1_2_2_2_1_1_1_1_1_1
              LONG %%2_2_1_1_1_1_1_1_2_2_2_1_1_1_1_1
              LONG %%2_2_2_1_1_1_1_1_1_2_2_2_1_1_1_1
              LONG %%1_2_2_2_1_1_1_1_1_1_2_2_2_1_1_1
              LONG %%1_1_2_2_2_1_1_1_1_1_1_2_2_2_1_1
              LONG %%0_0_0_2_2_2_0_0_0_0_1_1_2_2_2_1
              LONG %%0_0_0_0_2_2_2_0_0_0_1_1_1_2_2_2
              LONG %%0_0_0_0_0_2_2_2_0_0_1_1_1_1_2_2

' Extracted from file "profi_1px.bmp" at tile=(13, 3), size=(16, 16), palette index=(61)
profi_1px_tx13_ty3_bitmap    LONG
              LONG %%2_2_1_1_1_1_1_1_2_2_2_1_1_1_1_1
              LONG %%2_2_2_1_1_1_1_1_1_2_2_2_1_1_1_1
              LONG %%1_2_2_2_1_1_1_1_1_1_2_2_2_1_1_1
              LONG %%1_1_2_2_2_1_1_1_1_1_1_2_2_2_1_1
              LONG %%1_1_1_2_2_2_1_1_1_0_1_1_2_2_2_1
              LONG %%1_1_1_1_2_2_2_1_0_0_1_1_1_2_2_2
              LONG %%1_1_1_1_1_2_2_2_0_0_1_1_1_1_2_2
              LONG %%1_1_1_1_1_1_2_2_2_0_1_1_1_1_1_2
              LONG %%2_1_1_1_1_0_0_2_2_2_1_1_1_1_1_1
              LONG %%2_2_1_1_0_0_0_0_2_2_2_1_1_1_1_1
              LONG %%2_2_2_0_0_0_0_0_0_2_2_2_1_1_1_1
              LONG %%1_2_2_2_0_0_0_0_0_0_2_2_2_1_1_1
              LONG %%1_0_2_2_2_0_0_0_0_0_1_2_2_2_1_1
              LONG %%0_0_0_2_2_2_0_0_0_0_1_1_2_2_2_1
              LONG %%0_0_0_0_2_2_2_0_0_0_1_1_1_2_2_2
              LONG %%0_0_0_0_0_2_2_2_0_0_1_1_1_1_2_2

' Extracted from file "profi_1px.bmp" at tile=(14, 3), size=(16, 16), palette index=(62)
profi_1px_tx14_ty3_bitmap    LONG
              LONG %%1_1_0_0_0_0_0_0_1_1_1_0_0_0_0_0
              LONG %%1_1_1_0_0_0_0_0_0_1_1_1_0_0_0_0
              LONG %%0_1_1_1_0_2_3_2_0_0_1_1_1_0_0_0
              LONG %%0_0_1_1_1_2_3_2_0_0_0_1_1_1_0_0
              LONG %%0_0_0_1_1_1_3_2_2_0_0_0_1_1_1_0
              LONG %%0_0_0_0_1_1_1_2_2_0_0_0_0_1_1_1
              LONG %%0_0_0_2_2_1_1_1_2_2_0_0_0_0_1_1
              LONG %%0_0_0_2_2_2_1_1_1_2_0_0_0_0_0_1
              LONG %%1_2_2_2_2_2_3_1_1_1_0_0_0_0_0_0
              LONG %%1_1_0_2_2_2_3_2_1_1_1_0_0_0_0_0
              LONG %%1_1_1_2_2_2_3_2_2_1_1_1_0_0_0_0
              LONG %%0_1_1_1_2_2_3_2_2_0_1_1_1_0_0_0
              LONG %%0_0_1_1_1_2_3_2_2_0_0_1_1_1_0_0
              LONG %%0_0_0_1_1_1_3_2_0_0_0_0_1_1_1_0
              LONG %%0_0_0_0_1_1_1_2_0_0_0_0_0_1_1_1
              LONG %%0_0_0_0_0_1_1_1_0_0_0_0_0_0_1_1

' Extracted from file "profi_1px.bmp" at tile=(15, 3), size=(16, 16), palette index=(63)
profi_1px_tx15_ty3_bitmap    LONG
              LONG %%1_1_0_0_2_2_2_2_1_1_1_2_0_0_0_0
              LONG %%1_1_1_0_2_2_2_2_2_1_1_1_0_0_0_0
              LONG %%0_1_1_1_2_2_2_2_2_2_1_1_1_0_0_0
              LONG %%0_0_1_1_1_2_2_2_2_2_2_1_1_1_0_0
              LONG %%0_0_0_1_1_1_2_2_2_2_2_2_1_1_1_0
              LONG %%0_0_0_0_1_1_1_2_2_2_2_2_0_1_1_1
              LONG %%0_0_0_0_2_1_1_1_2_2_2_2_0_0_1_1
              LONG %%0_0_0_0_2_2_1_1_1_2_2_2_0_0_0_1
              LONG %%1_0_0_0_2_2_2_1_1_1_2_2_0_0_0_0
              LONG %%1_1_0_0_2_2_2_2_1_1_1_2_0_0_0_0
              LONG %%1_1_1_0_2_2_2_2_2_1_1_1_0_0_0_0
              LONG %%0_1_1_1_2_2_2_2_2_2_1_1_1_0_0_0
              LONG %%0_0_1_1_1_2_2_2_2_2_2_1_1_1_0_0
              LONG %%0_0_0_1_1_1_2_2_2_2_2_2_1_1_1_0
              LONG %%0_0_0_0_1_1_1_2_2_2_2_2_0_1_1_1
              LONG %%0_0_0_0_2_1_1_1_2_2_2_2_0_0_1_1

' Extracted from file "profi_1px.bmp" at tile=(0, 4), size=(16, 16), palette index=(64)
profi_1px_tx0_ty4_bitmap    LONG
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%1_1_1_1_1_1_1_1_0_0_0_0_0_0_0_0
              LONG %%1_1_1_1_1_1_1_1_1_1_0_0_0_0_0_0
              LONG %%1_1_1_1_1_1_1_1_1_1_1_0_0_0_0_0
              LONG %%1_1_1_1_1_1_1_1_1_1_1_1_0_0_0_0
              LONG %%1_1_1_1_1_1_1_1_1_1_1_1_0_0_0_0
              LONG %%1_1_1_1_1_1_1_1_1_1_1_1_1_0_0_0
              LONG %%1_1_1_1_1_1_1_1_1_1_1_1_1_0_0_0
              LONG %%1_1_1_1_1_1_1_1_1_1_1_1_1_0_0_0
              LONG %%1_1_1_1_1_1_1_1_1_1_1_1_1_0_0_0
              LONG %%1_1_1_1_1_1_1_1_1_1_1_1_1_0_0_0
              LONG %%0_0_0_1_1_1_1_1_1_1_1_1_1_0_0_0
              LONG %%0_0_0_1_1_1_1_1_1_1_1_1_1_0_0_0
              LONG %%0_0_0_1_1_1_1_1_1_1_1_1_1_0_0_0

' Extracted from file "profi_1px.bmp" at tile=(1, 4), size=(16, 16), palette index=(65)
profi_1px_tx1_ty4_bitmap    LONG
              LONG %%2_2_2_2_2_2_2_2_2_0_0_0_0_0_0_0
              LONG %%2_2_2_2_2_2_2_2_2_0_0_0_0_0_0_0
              LONG %%2_2_2_2_2_2_2_2_2_0_0_0_0_0_0_0
              LONG %%2_2_2_2_2_2_2_2_1_1_1_1_1_1_1_1
              LONG %%2_2_2_2_2_2_2_1_1_1_1_1_1_1_1_1
              LONG %%2_2_2_2_2_2_1_1_1_1_1_1_1_1_1_1
              LONG %%2_2_2_2_2_1_1_1_1_1_1_1_1_1_1_1
              LONG %%2_2_2_2_1_1_1_1_1_1_1_1_1_1_1_1
              LONG %%2_2_2_1_1_1_1_1_1_1_1_1_1_1_1_1
              LONG %%2_2_1_1_1_1_1_1_1_1_1_1_1_1_1_1
              LONG %%2_1_1_1_1_1_1_1_1_1_1_1_1_1_1_1
              LONG %%1_1_1_1_1_1_1_1_1_1_1_1_1_1_1_1
              LONG %%1_1_1_1_1_1_1_1_1_1_1_1_1_1_1_1
              LONG %%0_0_0_0_2_2_2_2_2_2_2_2_0_0_0_0
              LONG %%0_0_0_0_1_1_1_1_1_1_1_1_0_0_0_0
              LONG %%0_0_0_0_1_1_1_1_1_1_1_1_0_0_0_0

' Extracted from file "profi_1px.bmp" at tile=(2, 4), size=(16, 16), palette index=(66)
profi_1px_tx2_ty4_bitmap    LONG
              LONG %%1_1_1_1_1_1_1_1_1_1_1_1_1_1_1_1
              LONG %%1_1_1_1_1_1_1_1_1_1_1_1_1_1_1_1
              LONG %%1_1_1_1_1_1_1_1_1_1_1_1_1_1_1_1
              LONG %%1_1_1_1_1_1_1_1_1_1_1_1_1_1_1_1
              LONG %%1_1_1_1_1_1_1_1_1_1_1_1_1_1_1_1
              LONG %%1_1_1_1_1_1_1_1_1_1_1_1_1_1_1_1
              LONG %%1_1_1_1_1_1_1_1_1_1_1_1_1_1_1_1
              LONG %%1_1_1_1_1_1_1_1_1_1_1_1_1_1_1_1
              LONG %%1_1_1_1_1_1_1_1_1_1_1_1_1_1_1_1
              LONG %%1_1_1_1_1_1_1_1_1_1_1_1_1_1_1_1
              LONG %%1_1_1_1_1_1_1_1_1_1_1_1_1_1_1_1
              LONG %%1_1_1_1_1_1_1_1_1_1_1_1_1_1_1_1
              LONG %%1_1_1_1_1_1_1_1_1_1_1_1_1_1_1_2
              LONG %%1_1_1_1_1_1_1_1_1_1_1_1_1_1_0_0
              LONG %%1_1_1_1_1_1_1_1_1_1_1_1_1_0_0_0
              LONG %%1_1_1_1_1_1_1_1_1_1_1_0_0_0_0_0

' Extracted from file "profi_1px.bmp" at tile=(3, 4), size=(16, 16), palette index=(67)
profi_1px_tx3_ty4_bitmap    LONG
              LONG %%1_1_1_1_1_1_1_1_1_1_1_1_1_1_1_1
              LONG %%1_1_1_1_1_1_1_1_1_1_1_1_1_1_1_1
              LONG %%1_1_1_1_1_1_1_1_1_1_1_1_1_1_1_1
              LONG %%1_1_1_1_1_1_1_1_1_1_1_1_1_1_1_1
              LONG %%1_1_1_1_1_1_1_1_1_1_1_1_1_1_1_1
              LONG %%1_1_1_1_1_1_1_1_1_1_1_1_1_1_1_1
              LONG %%1_1_1_1_1_1_1_1_1_1_1_1_1_1_1_1
              LONG %%1_1_1_1_1_1_1_1_1_1_1_1_1_1_1_1
              LONG %%1_1_1_1_1_1_1_1_1_1_1_1_1_1_1_1
              LONG %%1_1_1_1_1_1_1_1_1_1_1_1_1_1_1_1
              LONG %%1_1_1_1_1_1_1_1_1_1_1_1_1_1_1_1
              LONG %%1_1_1_1_1_1_1_1_1_1_1_1_1_1_1_1
              LONG %%2_1_1_1_1_1_1_1_1_1_1_1_1_1_1_1
              LONG %%0_0_1_1_1_1_1_1_1_1_1_1_1_1_1_1
              LONG %%0_0_0_1_1_1_1_1_1_1_1_1_1_1_1_1
              LONG %%0_0_0_0_0_1_1_1_1_1_1_1_1_1_1_1

' Extracted from file "profi_1px.bmp" at tile=(4, 4), size=(16, 16), palette index=(68)
profi_1px_tx4_ty4_bitmap    LONG
              LONG %%0_0_0_0_0_0_0_2_2_2_2_2_2_2_2_2
              LONG %%0_0_0_0_0_0_0_2_2_2_2_2_2_2_2_2
              LONG %%0_0_0_0_0_0_0_2_2_2_2_2_2_2_2_2
              LONG %%1_1_1_1_1_1_1_1_2_2_2_2_2_2_2_2
              LONG %%1_1_1_1_1_1_1_1_1_2_2_2_2_2_2_2
              LONG %%1_1_1_1_1_1_1_1_1_1_2_2_2_2_2_2
              LONG %%1_1_1_1_1_1_1_1_1_1_1_2_2_2_2_2
              LONG %%1_1_1_1_1_1_1_1_1_1_1_1_2_2_2_2
              LONG %%1_1_1_1_1_1_1_1_1_1_1_1_1_2_2_2
              LONG %%1_1_1_1_1_1_1_1_1_1_1_1_1_1_2_2
              LONG %%1_1_1_1_1_1_1_1_1_1_1_1_1_1_1_2
              LONG %%1_1_1_1_1_1_1_1_1_1_1_1_1_1_1_1
              LONG %%1_1_1_1_1_1_1_1_1_1_1_1_1_1_1_1
              LONG %%0_0_0_0_2_2_2_2_2_2_2_2_0_0_0_0
              LONG %%0_0_0_0_1_1_1_1_1_1_1_1_0_0_0_0
              LONG %%0_0_0_0_1_1_1_1_1_1_1_1_0_0_0_0

' Extracted from file "profi_1px.bmp" at tile=(5, 4), size=(16, 16), palette index=(69)
profi_1px_tx5_ty4_bitmap    LONG
              LONG %%0_0_0_1_1_1_1_1_1_1_1_1_1_0_0_0
              LONG %%0_0_0_1_1_1_1_1_1_1_1_1_1_0_0_0
              LONG %%0_0_0_1_1_1_1_1_1_1_1_1_1_0_0_0
              LONG %%0_0_0_1_1_1_1_1_1_1_1_1_1_1_1_1
              LONG %%0_0_0_1_1_1_1_1_1_1_1_1_1_1_1_1
              LONG %%0_0_0_1_1_1_1_1_1_1_1_1_1_1_1_1
              LONG %%0_0_0_1_1_1_1_1_1_1_1_1_1_1_1_1
              LONG %%0_0_0_1_1_1_1_1_1_1_1_1_1_1_1_1
              LONG %%0_0_0_0_1_1_1_1_1_1_1_1_1_1_1_1
              LONG %%0_0_0_0_1_1_1_1_1_1_1_1_1_1_1_1
              LONG %%0_0_0_0_0_1_1_1_1_1_1_1_1_1_1_1
              LONG %%0_0_0_0_0_0_1_1_1_1_1_1_1_1_1_1
              LONG %%0_0_0_0_0_0_0_0_1_1_1_1_1_1_1_1
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0

' Extracted from file "profi_1px.bmp" at tile=(6, 4), size=(16, 16), palette index=(70)
profi_1px_tx6_ty4_bitmap    LONG
              LONG %%2_2_0_1_1_1_1_1_2_2_2_1_1_0_0_0
              LONG %%2_2_2_1_1_1_1_1_1_2_2_2_1_0_0_0
              LONG %%0_2_2_2_1_1_1_1_1_1_2_2_2_0_0_0
              LONG %%1_1_2_2_2_1_1_1_1_1_1_2_2_2_0_0
              LONG %%1_1_1_2_2_2_1_1_1_1_1_1_2_2_2_0
              LONG %%1_1_1_1_2_2_2_1_1_1_1_1_1_2_2_2
              LONG %%1_1_1_1_1_2_2_2_1_1_1_1_1_0_2_2
              LONG %%1_1_1_1_1_1_2_2_2_1_1_1_1_0_0_2
              LONG %%2_1_1_1_1_1_1_2_2_2_1_1_0_0_0_0
              LONG %%2_2_1_1_1_1_1_1_2_2_2_1_0_0_0_0
              LONG %%2_2_2_1_1_1_1_1_1_2_2_2_0_0_0_0
              LONG %%1_2_2_2_1_1_1_1_1_1_2_2_2_0_0_0
              LONG %%1_1_2_2_2_1_1_1_0_0_0_2_2_2_0_0
              LONG %%0_0_0_2_2_2_0_0_0_0_0_0_2_2_2_0
              LONG %%0_0_0_0_2_2_2_0_0_0_0_0_0_2_2_2
              LONG %%0_0_0_0_0_2_2_2_0_0_0_0_0_0_2_2

' Extracted from file "profi_1px.bmp" at tile=(7, 4), size=(16, 16), palette index=(71)
profi_1px_tx7_ty4_bitmap    LONG
              LONG %%2_2_0_0_0_1_1_1_2_2_2_1_1_1_1_1
              LONG %%2_2_2_0_0_1_1_1_1_2_2_2_1_1_1_1
              LONG %%0_2_2_2_0_1_1_1_1_1_2_2_2_1_1_1
              LONG %%0_0_2_2_2_1_1_1_1_1_1_2_2_2_1_1
              LONG %%0_0_0_2_2_2_1_1_1_1_1_1_2_2_2_1
              LONG %%0_0_0_0_2_2_2_1_1_1_1_1_1_2_2_2
              LONG %%0_0_0_0_0_2_2_2_1_1_1_1_1_1_2_2
              LONG %%0_0_0_0_0_1_2_2_2_1_1_1_1_1_1_2
              LONG %%2_0_0_0_0_1_1_2_2_2_1_1_1_1_1_1
              LONG %%2_2_0_0_0_1_1_1_2_2_2_1_1_1_1_1
              LONG %%2_2_2_0_0_1_1_1_1_2_2_2_1_1_1_1
              LONG %%0_2_2_2_0_1_1_1_1_1_2_2_2_1_1_1
              LONG %%0_0_2_2_2_0_1_1_1_1_1_2_2_2_1_1
              LONG %%0_0_0_2_2_2_1_1_1_1_1_1_2_2_2_1
              LONG %%0_0_0_0_2_2_2_1_1_1_1_1_1_2_2_2
              LONG %%0_0_0_0_0_2_2_2_0_0_0_0_0_0_2_2

' Extracted from file "profi_1px.bmp" at tile=(8, 4), size=(16, 16), palette index=(72)
profi_1px_tx8_ty4_bitmap    LONG
              LONG %%2_2_0_1_1_1_1_1_2_2_2_1_1_0_0_0
              LONG %%2_2_2_1_1_1_1_1_1_2_2_2_1_0_0_0
              LONG %%0_2_2_2_1_1_1_1_1_1_2_2_2_0_0_0
              LONG %%0_0_2_2_2_1_1_1_1_1_1_2_2_2_1_1
              LONG %%0_0_0_2_2_2_1_1_1_1_1_1_2_2_2_1
              LONG %%0_0_0_1_2_2_2_1_1_1_1_1_1_2_2_2
              LONG %%0_0_0_1_1_2_2_2_1_1_1_1_1_1_2_2
              LONG %%0_0_0_1_1_1_2_2_2_1_1_1_1_1_1_2
              LONG %%2_0_0_0_1_1_1_2_2_2_1_1_1_1_1_1
              LONG %%2_2_0_0_1_1_1_1_2_2_2_1_1_1_1_1
              LONG %%2_2_2_0_0_1_1_1_1_2_2_2_1_1_1_1
              LONG %%0_2_2_2_0_0_1_1_1_1_2_2_2_1_1_1
              LONG %%0_0_2_2_2_0_0_0_1_1_1_2_2_2_1_1
              LONG %%0_0_0_2_2_2_0_0_0_0_0_0_2_2_2_0
              LONG %%0_0_0_0_2_2_2_0_0_0_0_0_0_2_2_2
              LONG %%0_0_0_0_0_2_2_2_0_0_0_0_0_0_2_2

' Extracted from file "profi_1px.bmp" at tile=(9, 4), size=(16, 16), palette index=(73)
profi_1px_tx9_ty4_bitmap    LONG
              LONG %%2_2_3_3_3_3_3_3_2_2_2_3_3_3_3_3
              LONG %%2_2_2_1_1_1_1_1_1_2_2_2_1_1_1_1
              LONG %%1_2_2_2_1_1_1_1_1_1_2_2_2_1_1_1
              LONG %%1_1_2_2_2_1_1_1_1_1_1_2_2_2_1_1
              LONG %%1_1_1_2_2_2_1_1_1_1_1_1_2_2_2_1
              LONG %%1_1_1_1_2_2_2_1_1_1_1_1_1_2_2_2
              LONG %%1_1_1_1_1_2_2_2_1_1_1_1_1_1_2_2
              LONG %%1_1_1_1_1_1_2_2_2_1_1_1_1_1_1_2
              LONG %%2_1_1_1_1_1_1_2_2_2_1_1_1_1_1_1
              LONG %%2_2_1_1_1_1_1_1_2_2_2_1_1_1_1_1
              LONG %%2_2_2_1_1_1_1_1_1_2_2_2_1_1_1_1
              LONG %%1_2_2_2_1_1_1_1_1_1_2_2_2_1_1_1
              LONG %%1_1_2_2_2_1_1_1_1_1_1_2_2_2_1_1
              LONG %%1_1_1_2_2_2_1_1_1_1_1_1_2_2_2_1
              LONG %%1_1_1_1_2_2_2_1_1_1_1_1_1_2_2_2
              LONG %%3_3_3_3_3_2_2_2_3_3_3_3_3_3_2_2

' Extracted from file "profi_1px.bmp" at tile=(10, 4), size=(16, 16), palette index=(74)
profi_1px_tx10_ty4_bitmap    LONG
              LONG %%2_2_0_0_0_0_0_3_2_2_2_3_3_3_3_3
              LONG %%2_2_2_0_3_3_3_1_1_2_2_2_1_1_1_1
              LONG %%0_2_2_2_1_1_1_1_1_1_2_2_2_1_1_1
              LONG %%3_1_2_2_2_1_1_1_1_1_1_2_2_2_1_1
              LONG %%1_1_1_2_2_2_1_1_1_1_1_1_2_2_2_1
              LONG %%1_1_1_1_2_2_2_1_1_1_1_1_1_2_2_2
              LONG %%1_1_1_1_1_2_2_2_1_1_1_1_1_1_2_2
              LONG %%1_1_1_1_1_1_2_2_2_1_1_1_1_1_1_2
              LONG %%2_1_1_1_1_1_1_2_2_2_1_1_1_1_1_1
              LONG %%2_2_1_1_1_1_1_1_2_2_2_1_1_1_1_1
              LONG %%2_2_2_1_1_1_1_1_1_2_2_2_1_1_1_1
              LONG %%1_2_2_2_1_1_1_1_1_1_2_2_2_1_1_1
              LONG %%3_1_2_2_2_1_1_1_1_1_1_2_2_2_1_1
              LONG %%0_3_3_2_2_2_1_1_1_1_1_1_2_2_2_1
              LONG %%0_0_0_0_2_2_2_1_1_1_1_1_1_2_2_2
              LONG %%0_0_0_0_0_2_2_2_3_3_3_3_3_3_2_2

' Extracted from file "profi_1px.bmp" at tile=(11, 4), size=(16, 16), palette index=(75)
profi_1px_tx11_ty4_bitmap    LONG
              LONG %%1_1_2_2_2_2_0_0_1_1_1_0_0_0_0_0
              LONG %%1_1_1_2_2_2_0_0_0_1_1_1_0_0_0_0
              LONG %%2_1_1_1_2_2_0_0_0_0_1_1_1_0_0_0
              LONG %%2_2_1_1_1_2_0_0_0_0_0_1_1_1_0_0
              LONG %%2_2_2_1_1_1_0_0_0_0_0_0_1_1_1_0
              LONG %%2_2_2_2_1_1_1_0_0_0_0_0_0_1_1_1
              LONG %%2_2_2_2_2_1_1_1_0_0_0_0_0_0_1_1
              LONG %%2_2_2_2_2_2_1_1_1_0_0_0_0_0_0_1
              LONG %%1_2_2_2_2_2_0_1_1_1_0_0_0_0_0_0
              LONG %%1_1_2_2_2_2_0_0_1_1_1_0_0_0_0_0
              LONG %%1_1_1_2_2_2_0_0_0_1_1_1_0_0_0_0
              LONG %%2_1_1_1_2_2_0_0_0_0_1_1_1_0_0_0
              LONG %%2_2_1_1_1_2_0_0_0_0_0_1_1_1_0_0
              LONG %%2_2_2_1_1_1_0_0_0_0_0_0_1_1_1_0
              LONG %%2_2_2_2_1_1_1_0_0_0_0_0_0_1_1_1
              LONG %%2_2_2_2_2_1_1_1_0_0_0_0_0_0_1_1

' Extracted from file "profi_1px.bmp" at tile=(12, 4), size=(16, 16), palette index=(76)
profi_1px_tx12_ty4_bitmap    LONG
              LONG %%1_1_0_0_0_0_0_0_1_1_1_2_2_2_2_2
              LONG %%1_1_1_0_0_0_0_0_0_1_1_1_2_2_2_2
              LONG %%0_1_1_1_0_0_0_0_0_0_1_1_1_2_2_2
              LONG %%0_0_1_1_1_0_0_0_0_0_2_1_1_1_2_2
              LONG %%0_0_0_1_1_1_0_0_0_0_2_2_1_1_1_2
              LONG %%0_0_0_0_1_1_1_0_0_0_2_2_2_1_1_1
              LONG %%0_0_0_0_0_1_1_1_0_0_2_2_2_2_1_1
              LONG %%0_0_0_0_0_0_1_1_1_0_2_2_2_2_2_1
              LONG %%1_0_0_0_0_0_0_1_1_1_2_2_2_2_2_2
              LONG %%1_1_0_0_0_0_0_0_1_1_1_2_2_2_2_2
              LONG %%1_1_1_0_0_0_0_0_0_1_1_1_2_2_2_2
              LONG %%0_1_1_1_0_0_0_0_0_0_1_1_1_2_2_2
              LONG %%0_0_1_1_1_0_0_0_0_0_2_1_1_1_2_2
              LONG %%0_0_0_1_1_1_0_0_0_0_2_2_1_1_1_2
              LONG %%0_0_0_0_1_1_1_0_0_0_2_2_2_1_1_1
              LONG %%0_0_0_0_0_1_1_1_0_0_2_2_2_2_1_1

' Extracted from file "profi_1px.bmp" at tile=(13, 4), size=(16, 16), palette index=(77)
profi_1px_tx13_ty4_bitmap    LONG
              LONG %%2_2_1_1_1_1_0_0_2_2_2_0_0_0_0_0
              LONG %%2_2_2_1_1_1_0_0_0_2_2_2_0_0_0_0
              LONG %%1_2_2_2_1_1_0_0_0_0_2_2_2_0_0_0
              LONG %%1_1_2_2_2_1_0_0_0_0_0_2_2_2_0_0
              LONG %%1_1_1_2_2_2_0_0_0_0_0_0_2_2_2_0
              LONG %%1_1_1_1_2_2_2_0_0_0_0_0_0_2_2_2
              LONG %%1_1_1_1_1_2_2_2_0_0_0_0_0_0_2_2
              LONG %%1_1_1_1_1_1_2_2_2_0_0_0_0_0_0_2
              LONG %%2_1_1_1_1_1_1_2_2_2_0_0_0_0_0_0
              LONG %%2_2_1_1_1_1_1_1_2_2_2_0_0_0_0_0
              LONG %%2_2_2_1_1_1_1_1_1_2_2_2_0_0_0_0
              LONG %%1_2_2_2_1_1_1_1_1_1_2_2_2_0_0_0
              LONG %%1_1_2_2_2_1_1_1_1_1_1_2_2_2_0_0
              LONG %%1_1_1_2_2_2_1_1_1_1_1_1_2_2_2_0
              LONG %%1_1_1_1_2_2_2_1_1_1_1_1_1_2_2_2
              LONG %%1_1_1_1_1_2_2_2_1_1_1_1_1_1_2_2

' Extracted from file "profi_1px.bmp" at tile=(14, 4), size=(16, 16), palette index=(78)
profi_1px_tx14_ty4_bitmap    LONG
              LONG %%2_2_1_1_1_1_1_1_2_2_2_0_0_0_0_0
              LONG %%2_2_2_1_1_1_1_1_1_2_2_2_0_0_0_0
              LONG %%1_2_2_2_1_1_1_1_1_1_2_2_2_0_0_0
              LONG %%1_1_2_2_2_1_1_1_1_1_1_2_2_2_0_0
              LONG %%1_1_1_2_2_2_1_1_1_1_1_0_2_2_2_0
              LONG %%1_1_1_1_2_2_2_1_1_1_1_0_0_2_2_2
              LONG %%1_1_1_1_1_2_2_2_1_1_1_0_0_0_2_2
              LONG %%1_1_1_1_1_1_2_2_2_1_1_0_0_0_0_2
              LONG %%2_1_1_1_1_1_1_2_2_2_1_0_0_0_0_0
              LONG %%2_2_1_1_1_1_1_1_2_2_2_0_0_0_0_0
              LONG %%2_2_2_1_1_1_1_1_1_2_2_2_0_0_0_0
              LONG %%1_2_2_2_1_1_1_1_1_1_2_2_2_0_0_0
              LONG %%1_1_2_2_2_1_1_1_1_1_0_2_2_2_0_0
              LONG %%1_1_1_2_2_2_1_1_1_1_0_0_2_2_2_0
              LONG %%1_1_1_1_2_2_2_1_1_0_0_0_0_2_2_2
              LONG %%0_0_0_0_0_2_2_2_0_0_0_0_0_0_2_2

' Extracted from file "profi_1px.bmp" at tile=(15, 4), size=(16, 16), palette index=(79)
profi_1px_tx15_ty4_bitmap    LONG
              LONG %%2_2_1_1_1_1_1_1_2_2_2_1_1_1_1_1
              LONG %%2_2_2_1_1_1_1_1_1_2_2_2_1_1_1_1
              LONG %%1_2_2_2_1_1_1_1_1_1_2_2_2_1_1_1
              LONG %%1_1_2_2_2_1_1_1_1_1_1_2_2_2_1_1
              LONG %%1_1_1_2_2_2_0_1_1_1_1_1_2_2_2_1
              LONG %%1_1_1_1_2_2_2_0_1_1_1_1_1_2_2_2
              LONG %%1_1_1_1_1_2_2_2_0_1_1_1_1_1_2_2
              LONG %%1_1_1_1_1_1_2_2_2_0_1_1_1_1_1_2
              LONG %%2_1_1_1_1_1_0_2_2_2_0_1_1_1_1_1
              LONG %%2_2_1_1_1_1_0_0_2_2_2_0_1_1_1_1
              LONG %%2_2_2_1_1_1_0_0_0_2_2_2_0_1_1_1
              LONG %%1_2_2_2_1_1_0_0_0_0_2_2_2_0_1_1
              LONG %%1_1_2_2_2_1_0_0_0_0_0_2_2_2_0_1
              LONG %%1_1_1_2_2_2_0_0_0_0_0_0_2_2_2_0
              LONG %%1_1_1_1_2_2_2_0_0_0_0_0_0_2_2_2
              LONG %%1_1_1_1_1_2_2_2_0_0_0_0_0_0_2_2

' Extracted from file "profi_1px.bmp" at tile=(0, 5), size=(16, 16), palette index=(80)
profi_1px_tx0_ty5_bitmap    LONG
              LONG %%2_2_1_1_1_1_0_0_2_2_2_0_0_0_0_0
              LONG %%2_2_2_1_1_1_0_0_0_2_2_2_0_0_0_0
              LONG %%1_2_2_2_1_1_0_0_0_0_2_2_2_0_0_0
              LONG %%1_1_2_2_2_1_0_0_0_0_0_2_2_2_0_0
              LONG %%1_1_1_2_2_2_0_0_0_0_0_0_2_2_2_0
              LONG %%1_1_1_1_2_2_2_0_0_0_0_0_0_2_2_2
              LONG %%1_1_1_1_1_2_2_2_0_0_0_0_0_0_2_2
              LONG %%1_1_1_1_1_1_2_2_2_0_0_0_0_0_0_2
              LONG %%2_1_1_1_1_1_1_2_2_2_0_0_0_0_0_0
              LONG %%2_2_1_1_1_1_1_1_2_2_2_0_0_0_0_0
              LONG %%2_2_2_1_1_1_1_1_1_2_2_2_0_0_0_0
              LONG %%1_2_2_2_1_1_1_1_1_1_2_2_2_0_0_0
              LONG %%1_1_2_2_2_1_1_1_1_1_1_2_2_2_0_0
              LONG %%1_1_1_2_2_2_1_1_1_1_1_1_2_2_2_0
              LONG %%1_1_1_1_2_2_2_1_1_1_1_1_1_2_2_2
              LONG %%1_1_1_1_1_2_2_2_1_1_1_1_1_1_2_2

' Extracted from file "profi_1px.bmp" at tile=(1, 5), size=(16, 16), palette index=(81)
profi_1px_tx1_ty5_bitmap    LONG
              LONG %%2_2_0_0_0_0_0_0_2_2_2_1_1_1_1_1
              LONG %%2_2_2_0_0_0_0_0_0_2_2_2_1_1_1_1
              LONG %%0_2_2_2_0_0_0_0_0_0_2_2_2_1_1_1
              LONG %%0_0_2_2_2_0_0_0_0_0_1_2_2_2_1_1
              LONG %%0_0_0_2_2_2_0_0_0_0_1_1_2_2_2_1
              LONG %%0_0_0_0_2_2_2_0_0_0_1_1_1_2_2_2
              LONG %%0_0_0_0_0_2_2_2_0_1_1_1_1_1_2_2
              LONG %%0_0_0_0_0_0_2_2_2_1_1_1_1_1_1_2
              LONG %%2_0_0_0_0_0_0_2_2_2_1_1_1_1_1_1
              LONG %%2_2_0_0_0_0_1_1_2_2_2_1_1_1_1_1
              LONG %%2_2_2_0_0_1_1_1_1_2_2_2_1_1_1_1
              LONG %%0_2_2_2_1_1_1_1_1_1_2_2_2_1_1_1
              LONG %%0_0_2_2_2_1_1_1_1_1_1_2_2_2_1_1
              LONG %%0_0_1_2_2_2_1_1_1_1_1_1_2_2_2_1
              LONG %%0_1_1_1_2_2_2_1_1_1_1_1_1_2_2_2
              LONG %%1_1_1_1_1_2_2_2_1_1_1_1_1_1_2_2

' Extracted from file "profi_1px.bmp" at tile=(2, 5), size=(16, 16), palette index=(82)
profi_1px_tx2_ty5_bitmap    LONG
              LONG %%1_1_2_2_2_2_2_2_1_1_1_2_2_2_2_0
              LONG %%1_1_1_2_2_2_2_2_2_1_1_1_2_2_0_0
              LONG %%2_1_1_1_2_2_2_2_2_2_1_1_1_0_0_0
              LONG %%2_2_1_1_1_2_2_2_2_2_2_1_1_1_0_0
              LONG %%2_2_2_1_1_1_0_2_2_2_2_0_1_1_1_0
              LONG %%2_2_2_2_1_1_1_0_2_2_0_0_0_1_1_1
              LONG %%2_2_2_2_2_1_1_1_0_0_0_0_0_0_1_1
              LONG %%2_2_2_2_2_2_1_1_1_0_0_0_0_0_0_1
              LONG %%1_2_2_2_2_2_0_1_1_1_0_0_0_0_0_0
              LONG %%1_1_2_2_2_2_0_0_1_1_1_0_0_0_0_0
              LONG %%1_1_1_2_2_2_0_0_0_1_1_1_0_0_0_0
              LONG %%2_1_1_1_2_2_0_0_0_0_1_1_1_0_0_0
              LONG %%2_2_1_1_1_2_0_0_0_0_0_1_1_1_0_0
              LONG %%2_2_2_1_1_1_0_0_0_0_0_0_1_1_1_0
              LONG %%2_2_2_2_1_1_1_0_0_0_0_0_0_1_1_1
              LONG %%2_2_2_2_2_1_1_1_0_0_0_0_0_0_1_1

' Extracted from file "profi_1px.bmp" at tile=(3, 5), size=(16, 16), palette index=(83)
profi_1px_tx3_ty5_bitmap    LONG
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0

' Extracted from file "profi_1px.bmp" at tile=(4, 5), size=(16, 16), palette index=(84)
profi_1px_tx4_ty5_bitmap    LONG
              LONG %%1_1_0_0_0_0_0_0_1_1_1_0_0_0_0_0
              LONG %%1_1_1_0_0_0_0_0_0_1_1_1_0_0_0_0
              LONG %%0_1_1_1_0_2_3_2_0_0_1_1_1_0_0_0
              LONG %%0_0_1_1_1_2_3_2_0_0_0_1_1_1_0_0
              LONG %%0_0_0_1_1_1_3_2_2_0_0_0_1_1_1_0
              LONG %%0_0_0_0_1_1_1_2_2_0_0_0_0_1_1_1
              LONG %%0_0_0_2_2_1_1_1_2_2_0_0_0_0_1_1
              LONG %%0_0_0_2_2_2_1_1_1_2_0_0_0_0_0_1
              LONG %%1_2_2_2_2_2_3_1_1_1_0_0_0_0_0_0
              LONG %%1_1_0_2_2_2_3_2_1_1_1_0_0_0_0_0
              LONG %%1_1_1_2_2_2_3_2_2_1_1_1_0_0_0_0
              LONG %%0_1_1_1_2_2_3_2_2_0_1_1_1_0_0_0
              LONG %%0_0_1_1_1_2_3_2_2_0_0_1_1_1_0_0
              LONG %%0_0_0_1_1_1_3_2_0_0_0_0_1_1_1_0
              LONG %%0_0_0_0_1_1_1_2_0_0_0_0_0_1_1_1
              LONG %%0_0_0_0_0_1_1_1_0_0_0_0_0_0_1_1

' Extracted from file "profi_1px.bmp" at tile=(5, 5), size=(16, 16), palette index=(85)
profi_1px_tx5_ty5_bitmap    LONG
              LONG %%1_1_0_0_2_2_2_2_1_1_1_2_0_0_0_0
              LONG %%1_1_1_0_2_2_2_2_2_1_1_1_0_0_0_0
              LONG %%0_1_1_1_2_2_2_2_2_2_1_1_1_0_0_0
              LONG %%0_0_1_1_1_2_2_2_2_2_2_1_1_1_0_0
              LONG %%0_0_0_1_1_1_2_2_2_2_2_2_1_1_1_0
              LONG %%0_0_0_0_1_1_1_2_2_2_2_2_0_1_1_1
              LONG %%0_0_0_0_2_1_1_1_2_2_2_2_0_0_1_1
              LONG %%0_0_0_0_2_2_1_1_1_2_2_2_0_0_0_1
              LONG %%1_0_0_0_2_2_2_1_1_1_2_2_0_0_0_0
              LONG %%1_1_0_0_2_2_2_2_1_1_1_2_0_0_0_0
              LONG %%1_1_1_0_2_2_2_2_2_1_1_1_0_0_0_0
              LONG %%0_1_1_1_2_2_2_2_2_2_1_1_1_0_0_0
              LONG %%0_0_1_1_1_2_2_2_2_2_2_1_1_1_0_0
              LONG %%0_0_0_1_1_1_2_2_2_2_2_2_1_1_1_0
              LONG %%0_0_0_0_1_1_1_2_2_2_2_2_0_1_1_1
              LONG %%0_0_0_0_2_1_1_1_2_2_2_2_0_0_1_1

' Extracted from file "profi_1px.bmp" at tile=(6, 5), size=(16, 16), palette index=(86)
profi_1px_tx6_ty5_bitmap    LONG
              LONG %%2_2_1_1_1_1_1_1_2_2_2_0_0_0_0_0
              LONG %%2_2_2_1_1_1_1_1_1_2_2_2_0_0_0_0
              LONG %%1_2_2_2_1_1_1_1_1_1_2_2_2_0_0_0
              LONG %%1_1_2_2_2_1_1_1_1_1_1_2_2_2_0_0
              LONG %%1_1_1_2_2_2_1_1_1_1_1_0_2_2_2_0
              LONG %%1_1_1_1_2_2_2_1_1_1_1_0_0_2_2_2
              LONG %%1_1_1_1_1_2_2_2_1_1_1_0_0_0_2_2
              LONG %%1_1_1_1_1_1_2_2_2_1_1_0_0_0_0_2
              LONG %%2_1_1_1_1_1_1_2_2_2_1_0_0_0_0_0
              LONG %%2_2_1_1_1_1_1_1_2_2_2_0_0_0_0_0
              LONG %%2_2_2_1_1_1_1_1_1_2_2_2_0_0_0_0
              LONG %%1_2_2_2_1_1_1_1_1_1_2_2_2_0_0_0
              LONG %%1_1_2_2_2_1_1_1_1_1_0_2_2_2_0_0
              LONG %%1_1_1_2_2_2_1_1_1_1_0_0_2_2_2_0
              LONG %%1_1_1_1_2_2_2_1_1_0_0_0_0_2_2_2
              LONG %%0_0_0_0_0_2_2_2_0_0_0_0_0_0_2_2

' Extracted from file "profi_1px.bmp" at tile=(7, 5), size=(16, 16), palette index=(87)
profi_1px_tx7_ty5_bitmap    LONG
              LONG %%2_2_1_1_1_1_1_1_2_2_2_1_1_1_1_1
              LONG %%2_2_2_1_1_1_1_1_1_2_2_2_1_1_1_1
              LONG %%1_2_2_2_1_1_1_1_1_1_2_2_2_1_1_1
              LONG %%1_1_2_2_2_1_1_1_1_1_1_2_2_2_1_1
              LONG %%1_1_1_2_2_2_0_1_1_1_1_1_2_2_2_1
              LONG %%1_1_1_1_2_2_2_0_1_1_1_1_1_2_2_2
              LONG %%1_1_1_1_1_2_2_2_0_1_1_1_1_1_2_2
              LONG %%1_1_1_1_1_1_2_2_2_0_1_1_1_1_1_2
              LONG %%2_1_1_1_1_1_0_2_2_2_0_1_1_1_1_1
              LONG %%2_2_1_1_1_1_0_0_2_2_2_0_1_1_1_1
              LONG %%2_2_2_1_1_1_0_0_0_2_2_2_0_1_1_1
              LONG %%1_2_2_2_1_1_0_0_0_0_2_2_2_0_1_1
              LONG %%1_1_2_2_2_1_0_0_0_0_0_2_2_2_0_1
              LONG %%1_1_1_2_2_2_0_0_0_0_0_0_2_2_2_0
              LONG %%1_1_1_1_2_2_2_0_0_0_0_0_0_2_2_2
              LONG %%1_1_1_1_1_2_2_2_0_0_0_0_0_0_2_2

' Extracted from file "profi_1px.bmp" at tile=(8, 5), size=(16, 16), palette index=(88)
profi_1px_tx8_ty5_bitmap    LONG
              LONG %%0_1_1_1_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%1_1_1_1_1_0_0_0_0_0_0_0_0_0_0_0
              LONG %%1_1_1_1_1_1_0_0_0_0_0_0_0_0_0_0
              LONG %%1_1_1_1_1_1_1_0_0_0_0_0_0_0_0_0
              LONG %%1_1_1_1_1_1_0_0_0_0_0_0_0_0_0_0
              LONG %%1_1_1_1_1_0_0_0_0_0_0_0_0_0_0_0
              LONG %%1_1_1_1_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%1_1_1_0_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%1_1_1_0_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%1_1_1_1_1_1_0_0_0_0_0_0_0_0_0_0
              LONG %%1_1_1_1_1_0_0_0_0_0_0_0_0_0_0_0
              LONG %%1_1_1_1_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%1_1_1_0_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%1_1_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%1_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0

' Extracted from file "profi_1px.bmp" at tile=(9, 5), size=(16, 16), palette index=(89)
profi_1px_tx9_ty5_bitmap    LONG
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_1
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_1_1
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_1_1_1
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_1_1_1
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_1_1_1_1
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_1_1_1_1
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_1_1_1_1
              LONG %%0_0_0_0_0_0_0_0_0_1_1_1_1_1_1_1
              LONG %%0_0_0_0_0_0_0_0_0_0_1_1_1_1_1_1
              LONG %%0_0_0_0_0_0_0_0_0_0_0_1_1_1_1_1
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_1_1_1_1
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_1_1_1
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_1_1
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_1

' Extracted from file "profi_1px.bmp" at tile=(10, 5), size=(16, 16), palette index=(90)
profi_1px_tx10_ty5_bitmap    LONG
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%1_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%1_1_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%1_1_1_0_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%1_1_1_0_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%1_1_1_1_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%1_1_1_1_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%1_1_1_1_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%1_1_1_1_1_1_1_0_0_0_0_0_0_0_0_0
              LONG %%1_1_1_1_1_1_0_0_0_0_0_0_0_0_0_0
              LONG %%1_1_1_1_1_0_0_0_0_0_0_0_0_0_0_0
              LONG %%1_1_1_1_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%1_1_1_0_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%1_1_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%1_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0

' Extracted from file "profi_1px.bmp" at tile=(11, 5), size=(16, 16), palette index=(91)
profi_1px_tx11_ty5_bitmap    LONG
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_1_1_1_0
              LONG %%0_0_0_0_0_0_0_0_0_0_0_1_1_1_1_1
              LONG %%0_0_0_0_0_0_0_0_0_0_1_1_1_1_1_1
              LONG %%0_0_0_0_0_0_0_0_0_1_1_1_1_1_1_1
              LONG %%0_0_0_0_0_0_0_0_0_0_1_1_1_1_1_1
              LONG %%0_0_0_0_0_0_0_0_0_0_0_1_1_1_1_1
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_1_1_1_1
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_1_1_1
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_1_1_1
              LONG %%0_0_0_0_0_0_0_0_0_0_1_1_1_1_1_1
              LONG %%0_0_0_0_0_0_0_0_0_0_0_1_1_1_1_1
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_1_1_1_1
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_1_1_1
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_1_1
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_1
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0

' Extracted from file "profi_1px.bmp" at tile=(12, 5), size=(16, 16), palette index=(92)
profi_1px_tx12_ty5_bitmap    LONG
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%1_1_1_1_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%1_1_1_1_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%1_1_1_1_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%1_1_1_1_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%1_1_1_1_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%1_1_1_1_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%1_1_1_1_1_1_1_0_0_0_0_0_0_0_0_0
              LONG %%1_1_1_1_1_1_0_0_0_0_0_0_0_0_0_0
              LONG %%1_1_1_1_1_0_0_0_0_0_0_0_0_0_0_0
              LONG %%1_1_1_1_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%1_1_1_0_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%1_1_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%1_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0

' Extracted from file "profi_1px.bmp" at tile=(13, 5), size=(16, 16), palette index=(93)
profi_1px_tx13_ty5_bitmap    LONG
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_1_1_1_1
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_1_1_1_1
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_1_1_1_1
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_1_1_1_1
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_1_1_1_1
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_1_1_1_1
              LONG %%0_0_0_0_0_0_0_0_0_1_1_1_1_1_1_1
              LONG %%0_0_0_0_0_0_0_0_0_0_1_1_1_1_1_1
              LONG %%0_0_0_0_0_0_0_0_0_0_0_1_1_1_1_1
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_1_1_1_1
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_1_1_1
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_1_1
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_1

' Extracted from file "profi_1px.bmp" at tile=(14, 5), size=(16, 16), palette index=(94)
profi_1px_tx14_ty5_bitmap    LONG
              LONG %%1_1_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%1_1_1_1_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%1_2_1_1_1_1_0_0_0_0_0_0_0_0_0_0
              LONG %%1_1_2_2_1_1_1_0_0_0_0_0_0_0_0_0
              LONG %%2_1_1_1_2_1_1_1_0_0_0_0_0_0_0_0
              LONG %%1_2_1_1_1_1_1_1_0_0_0_0_0_0_0_0
              LONG %%2_1_2_1_1_0_0_1_1_0_0_0_0_0_0_0
              LONG %%2_2_2_1_1_0_0_0_1_0_0_0_0_0_0_0
              LONG %%1_2_1_2_1_0_0_0_1_1_0_0_0_0_0_0
              LONG %%2_2_2_1_1_1_0_0_0_1_0_0_0_0_0_0
              LONG %%1_2_2_2_1_1_0_0_0_0_0_0_0_0_0_0
              LONG %%1_2_1_2_2_1_1_0_0_0_0_0_0_0_0_0
              LONG %%1_1_2_1_2_1_1_1_0_0_0_0_0_0_0_0
              LONG %%1_1_1_1_1_2_1_1_1_0_0_0_0_0_0_0
              LONG %%0_0_1_1_1_1_1_1_1_0_0_0_0_0_0_0
              LONG %%0_0_0_0_0_0_1_1_1_1_0_0_0_0_0_0

' Extracted from file "profi_1px.bmp" at tile=(15, 5), size=(16, 16), palette index=(95)
profi_1px_tx15_ty5_bitmap    LONG
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_1_1
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_1_1_1_1
              LONG %%0_0_0_0_0_0_0_0_0_0_1_1_1_1_2_1
              LONG %%0_0_0_0_0_0_0_0_0_1_1_1_2_2_1_1
              LONG %%0_0_0_0_0_0_0_0_1_1_1_2_1_1_1_2
              LONG %%0_0_0_0_0_0_0_0_1_1_1_1_1_1_2_1
              LONG %%0_0_0_0_0_0_0_1_1_0_0_1_1_2_1_2
              LONG %%0_0_0_0_0_0_0_1_0_0_0_1_1_2_2_2
              LONG %%0_0_0_0_0_0_1_1_0_0_0_1_2_1_2_1
              LONG %%0_0_0_0_0_0_1_0_0_0_1_1_1_2_2_2
              LONG %%0_0_0_0_0_0_0_0_0_0_1_1_2_2_2_1
              LONG %%0_0_0_0_0_0_0_0_0_1_1_2_2_1_2_1
              LONG %%0_0_0_0_0_0_0_0_1_1_1_2_1_2_1_1
              LONG %%0_0_0_0_0_0_0_1_1_1_2_1_1_1_1_1
              LONG %%0_0_0_0_0_0_0_1_1_1_1_1_1_1_0_0
              LONG %%0_0_0_0_0_0_1_1_1_1_0_0_0_0_0_0

' Extracted from file "profi_1px.bmp" at tile=(0, 6), size=(16, 16), palette index=(96)
profi_1px_tx0_ty6_bitmap    LONG
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%1_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%1_1_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%1_1_1_0_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%1_1_1_0_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%1_1_1_1_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%1_1_1_1_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%1_1_1_1_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%1_1_1_1_1_1_1_0_0_0_0_0_0_0_0_0
              LONG %%1_1_1_1_1_1_0_0_0_0_0_0_0_0_0_0
              LONG %%1_1_1_1_1_0_0_0_0_0_0_0_0_0_0_0
              LONG %%1_1_1_1_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%1_1_1_0_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%1_1_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%1_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0

' Extracted from file "profi_1px.bmp" at tile=(1, 6), size=(16, 16), palette index=(97)
profi_1px_tx1_ty6_bitmap    LONG
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_1_1_1_0
              LONG %%0_0_0_0_0_0_0_0_0_0_0_1_1_1_1_1
              LONG %%0_0_0_0_0_0_0_0_0_0_1_1_1_1_1_1
              LONG %%0_0_0_0_0_0_0_0_0_1_1_1_1_1_1_1
              LONG %%0_0_0_0_0_0_0_0_0_0_1_1_1_1_1_1
              LONG %%0_0_0_0_0_0_0_0_0_0_0_1_1_1_1_1
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_1_1_1_1
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_1_1_1
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_1_1_1
              LONG %%0_0_0_0_0_0_0_0_0_0_1_1_1_1_1_1
              LONG %%0_0_0_0_0_0_0_0_0_0_0_1_1_1_1_1
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_1_1_1_1
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_1_1_1
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_1_1
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_1
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0

' Extracted from file "profi_1px.bmp" at tile=(2, 6), size=(16, 16), palette index=(98)
profi_1px_tx2_ty6_bitmap    LONG
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%0_0_0_0_0_0_1_1_1_1_0_0_0_0_0_0
              LONG %%0_0_0_0_0_0_1_1_1_1_0_0_0_0_0_0
              LONG %%0_0_0_0_0_0_1_1_1_1_0_0_0_0_0_0
              LONG %%0_0_0_0_0_0_1_1_1_1_0_0_0_0_0_0
              LONG %%0_0_0_0_0_0_1_1_1_1_0_0_0_0_0_0
              LONG %%0_0_0_0_0_0_1_1_1_1_0_0_0_0_0_0
              LONG %%0_0_0_0_0_0_1_1_1_1_0_0_0_0_0_0
              LONG %%0_0_0_0_0_0_1_1_1_1_0_0_0_0_0_0
              LONG %%0_0_0_0_0_0_1_1_1_1_0_0_0_0_0_0
              LONG %%0_0_0_0_0_0_1_1_1_1_0_0_0_0_0_0
              LONG %%0_0_0_0_1_1_1_1_1_1_1_1_0_0_0_0
              LONG %%0_0_0_0_0_1_1_1_1_1_1_0_0_0_0_0
              LONG %%0_0_0_0_0_0_1_1_1_1_0_0_0_0_0_0
              LONG %%0_0_0_0_0_0_0_1_1_0_0_0_0_0_0_0
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0

' Extracted from file "profi_1px.bmp" at tile=(3, 6), size=(16, 16), palette index=(99)
profi_1px_tx3_ty6_bitmap    LONG
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%1_1_1_1_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%1_1_1_1_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%1_1_1_1_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%1_1_1_1_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%1_1_1_1_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%1_1_1_1_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%1_1_1_1_1_1_1_0_0_0_0_0_0_0_0_0
              LONG %%1_1_1_1_1_1_0_0_0_0_0_0_0_0_0_0
              LONG %%1_1_1_1_1_0_0_0_0_0_0_0_0_0_0_0
              LONG %%1_1_1_1_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%1_1_1_0_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%1_1_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%1_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0

' Extracted from file "profi_1px.bmp" at tile=(4, 6), size=(16, 16), palette index=(100)
profi_1px_tx4_ty6_bitmap    LONG
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_1_1_1
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_1_1_1
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_1_1_1
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_1_1_1
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_1_1_1
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_1_1_1
              LONG %%0_0_0_0_0_0_0_0_0_0_1_1_1_1_1_1
              LONG %%0_0_0_0_0_0_0_0_0_0_0_1_1_1_1_1
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_1_1_1_1
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_1_1_1
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_1_1
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_1
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0

' Extracted from file "profi_1px.bmp" at tile=(5, 6), size=(16, 16), palette index=(101)
profi_1px_tx5_ty6_bitmap    LONG
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%0_0_0_0_0_0_0_1_0_0_0_0_0_0_0_0
              LONG %%0_0_0_0_0_0_1_1_1_0_0_0_0_0_0_0
              LONG %%0_0_0_0_0_1_1_1_1_1_0_0_0_0_0_0
              LONG %%0_0_0_0_1_1_1_1_1_1_1_0_0_0_0_1
              LONG %%0_0_0_0_0_1_1_1_1_1_1_1_0_0_1_1
              LONG %%0_0_0_0_0_0_1_1_1_1_1_1_1_1_1_1
              LONG %%0_0_0_0_0_0_0_1_1_1_1_1_1_1_1_1
              LONG %%0_0_0_0_0_0_0_0_1_1_1_1_1_1_1_1
              LONG %%0_0_0_0_0_0_0_0_0_1_1_1_1_1_1_1
              LONG %%0_0_0_0_0_0_0_0_0_1_1_1_1_1_1_1
              LONG %%0_0_0_0_0_0_0_0_1_1_1_1_1_1_1_1
              LONG %%0_0_0_0_0_0_0_1_1_1_1_1_1_1_1_1

' Extracted from file "profi_1px.bmp" at tile=(6, 6), size=(16, 16), palette index=(102)
profi_1px_tx6_ty6_bitmap    LONG
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%0_0_0_0_0_0_0_0_1_0_0_0_0_0_0_0
              LONG %%0_0_0_0_0_0_0_1_1_1_0_0_0_0_0_0
              LONG %%0_0_0_0_0_0_1_1_1_1_1_0_0_0_0_0
              LONG %%1_0_0_0_0_1_1_1_1_1_1_1_0_0_0_0
              LONG %%1_1_0_0_1_1_1_1_1_1_1_0_0_0_0_0
              LONG %%1_1_1_1_1_1_1_1_1_1_0_0_0_0_0_0
              LONG %%1_1_1_1_1_1_1_1_1_0_0_0_0_0_0_0
              LONG %%1_1_1_1_1_1_1_1_0_0_0_0_0_0_0_0
              LONG %%1_1_1_1_1_1_1_0_0_0_0_0_0_0_0_0
              LONG %%1_1_1_1_1_1_1_0_0_0_0_0_0_0_0_0
              LONG %%1_1_1_1_1_1_1_1_0_0_0_0_0_0_0_0
              LONG %%1_1_1_1_1_1_1_1_1_0_0_0_0_0_0_0

' Extracted from file "profi_1px.bmp" at tile=(7, 6), size=(16, 16), palette index=(103)
profi_1px_tx7_ty6_bitmap    LONG
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%0_0_0_0_0_0_0_1_0_0_0_0_0_0_0_0
              LONG %%0_0_0_0_0_0_1_1_1_0_0_0_0_0_0_0
              LONG %%0_0_0_0_0_1_1_1_1_1_0_0_0_0_0_0
              LONG %%0_0_0_0_1_1_1_1_1_1_1_0_0_0_0_1
              LONG %%0_0_0_0_0_1_1_1_1_1_1_1_0_0_1_1
              LONG %%0_0_0_0_0_0_1_1_1_1_1_1_1_1_1_1
              LONG %%0_0_0_0_0_0_0_1_1_1_1_1_1_1_1_1
              LONG %%0_0_0_0_0_0_0_0_1_1_1_1_1_1_1_1
              LONG %%0_0_0_0_0_0_0_0_0_1_1_1_1_1_1_1
              LONG %%0_0_0_0_0_0_0_0_0_1_1_1_1_1_1_1
              LONG %%0_0_0_0_0_0_0_0_1_1_1_1_1_1_1_1
              LONG %%0_0_0_0_0_0_0_1_1_1_1_1_1_1_1_1

' Extracted from file "profi_1px.bmp" at tile=(8, 6), size=(16, 16), palette index=(104)
profi_1px_tx8_ty6_bitmap    LONG
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%0_0_0_0_0_0_0_0_1_0_0_0_0_0_0_0
              LONG %%0_0_0_0_0_0_0_1_1_1_0_0_0_0_0_0
              LONG %%0_0_0_0_0_0_1_1_1_1_1_0_0_0_0_0
              LONG %%1_0_0_0_0_1_1_1_1_1_1_1_0_0_0_0
              LONG %%1_1_0_0_1_1_1_1_1_1_1_0_0_0_0_0
              LONG %%1_1_1_1_1_1_1_1_1_1_0_0_0_0_0_0
              LONG %%1_1_1_1_1_1_1_1_1_0_0_0_0_0_0_0
              LONG %%1_1_1_1_1_1_1_1_0_0_0_0_0_0_0_0
              LONG %%1_1_1_1_1_1_1_0_0_0_0_0_0_0_0_0
              LONG %%1_1_1_1_1_1_1_0_0_0_0_0_0_0_0_0
              LONG %%1_1_1_1_1_1_1_1_0_0_0_0_0_0_0_0
              LONG %%1_1_1_1_1_1_1_1_1_0_0_0_0_0_0_0

' Extracted from file "profi_1px.bmp" at tile=(9, 6), size=(16, 16), palette index=(105)
profi_1px_tx9_ty6_bitmap    LONG
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%0_0_0_0_0_0_1_1_1_1_0_0_0_0_0_0
              LONG %%0_0_0_0_0_0_1_1_1_1_0_0_0_0_0_0
              LONG %%0_0_0_0_0_0_1_1_1_1_0_0_0_0_0_0
              LONG %%0_0_0_0_0_0_1_1_1_1_0_0_0_0_0_0
              LONG %%0_0_0_0_0_0_1_1_1_1_0_0_0_0_0_0
              LONG %%0_0_0_0_0_0_1_1_1_1_0_0_0_0_0_0
              LONG %%0_0_0_0_0_0_1_1_1_1_0_0_0_0_0_0
              LONG %%0_0_0_0_0_0_1_1_1_1_0_0_0_0_0_0
              LONG %%0_0_0_0_0_0_1_1_1_1_0_0_0_0_0_0
              LONG %%0_0_0_0_0_0_1_1_1_1_0_0_0_0_0_0
              LONG %%0_0_0_0_1_1_1_1_1_1_1_1_0_0_0_0
              LONG %%0_0_0_0_0_1_1_1_1_1_1_0_0_0_0_0
              LONG %%0_0_0_0_0_0_1_1_1_1_0_0_0_0_0_0
              LONG %%0_0_0_0_0_0_0_1_1_0_0_0_0_0_0_0
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0

' Extracted from file "profi_1px.bmp" at tile=(10, 6), size=(16, 16), palette index=(106)
profi_1px_tx10_ty6_bitmap    LONG
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%1_1_1_1_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%1_1_1_1_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%1_1_1_1_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%1_1_1_1_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%1_1_1_1_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%1_1_1_1_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%1_1_1_1_1_1_1_0_0_0_0_0_0_0_0_0
              LONG %%1_1_1_1_1_1_0_0_0_0_0_0_0_0_0_0
              LONG %%1_1_1_1_1_0_0_0_0_0_0_0_0_0_0_0
              LONG %%1_1_1_1_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%1_1_1_0_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%1_1_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%1_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0

' Extracted from file "profi_1px.bmp" at tile=(11, 6), size=(16, 16), palette index=(107)
profi_1px_tx11_ty6_bitmap    LONG
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_1_1_1
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_1_1_1
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_1_1_1
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_1_1_1
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_1_1_1
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_1_1_1
              LONG %%0_0_0_0_0_0_0_0_0_0_1_1_1_1_1_1
              LONG %%0_0_0_0_0_0_0_0_0_0_0_1_1_1_1_1
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_1_1_1_1
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_1_1_1
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_1_1
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_1
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0

' Extracted from file "profi_1px.bmp" at tile=(12, 6), size=(16, 16), palette index=(108)
profi_1px_tx12_ty6_bitmap    LONG
              LONG %%1_1_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%1_1_1_1_0_0_0_0_0_0_0_0_0_0_0_0
              LONG %%1_2_1_1_1_1_0_0_0_0_0_0_0_0_0_0
              LONG %%1_1_2_2_1_1_1_0_0_0_0_0_0_0_0_0
              LONG %%2_1_1_1_2_1_1_1_0_0_0_0_0_0_0_0
              LONG %%1_2_1_1_1_1_1_1_0_0_0_0_0_0_0_0
              LONG %%2_1_2_1_1_0_0_1_1_0_0_0_0_0_0_0
              LONG %%2_2_2_1_1_0_0_0_1_0_0_0_0_0_0_0
              LONG %%1_2_1_2_1_0_0_0_1_1_0_0_0_0_0_0
              LONG %%2_2_2_1_1_1_0_0_0_1_0_0_0_0_0_0
              LONG %%1_2_2_2_1_1_0_0_0_0_0_0_0_0_0_0
              LONG %%1_2_1_2_2_1_1_0_0_0_0_0_0_0_0_0
              LONG %%1_1_2_1_2_1_1_1_0_0_0_0_0_0_0_0
              LONG %%1_1_1_1_1_2_1_1_1_0_0_0_0_0_0_0
              LONG %%0_0_1_1_1_1_1_1_1_0_0_0_0_0_0_0
              LONG %%0_0_0_0_0_0_1_1_1_1_0_0_0_0_0_0

' Extracted from file "profi_1px.bmp" at tile=(13, 6), size=(16, 16), palette index=(109)
profi_1px_tx13_ty6_bitmap    LONG
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_1_1
              LONG %%0_0_0_0_0_0_0_0_0_0_0_0_1_1_1_1
              LONG %%0_0_0_0_0_0_0_0_0_0_1_1_1_1_2_1
              LONG %%0_0_0_0_0_0_0_0_0_1_1_1_2_2_1_1
              LONG %%0_0_0_0_0_0_0_0_1_1_1_2_1_1_1_2
              LONG %%0_0_0_0_0_0_0_0_1_1_1_1_1_1_2_1
              LONG %%0_0_0_0_0_0_0_1_1_0_0_1_1_2_1_2
              LONG %%0_0_0_0_0_0_0_1_0_0_0_1_1_2_2_2
              LONG %%0_0_0_0_0_0_1_1_0_0_0_1_2_1_2_1
              LONG %%0_0_0_0_0_0_1_0_0_0_1_1_1_2_2_2
              LONG %%0_0_0_0_0_0_0_0_0_0_1_1_2_2_2_1
              LONG %%0_0_0_0_0_0_0_0_0_1_1_2_2_1_2_1
              LONG %%0_0_0_0_0_0_0_0_1_1_1_2_1_2_1_1
              LONG %%0_0_0_0_0_0_0_1_1_1_2_1_1_1_1_1
              LONG %%0_0_0_0_0_0_0_1_1_1_1_1_1_1_0_0
              LONG %%0_0_0_0_0_0_1_1_1_1_0_0_0_0_0_0

' Extracted from file "profi_1px.bmp" at tile=(14, 6), size=(16, 16), palette index=(110)
profi_1px_tx14_ty6_bitmap    LONG
              LONG %%2_2_1_1_1_1_1_1_2_2_2_1_1_1_1_1
              LONG %%2_2_2_1_1_1_1_1_1_2_2_2_1_1_1_1
              LONG %%0_2_2_2_1_1_1_1_1_1_2_2_2_1_1_1
              LONG %%0_0_2_2_2_1_1_1_1_1_1_2_2_2_1_1
              LONG %%0_0_0_2_2_2_1_1_1_0_1_1_2_2_2_1
              LONG %%0_0_0_0_2_2_2_1_0_0_1_1_1_2_2_2
              LONG %%0_0_0_0_0_2_2_2_0_0_1_1_1_1_2_2
              LONG %%0_0_0_0_0_0_2_2_2_0_1_1_1_1_1_2
              LONG %%2_0_0_0_0_0_0_2_2_2_1_1_1_1_1_1
              LONG %%2_2_0_0_0_0_0_0_2_2_2_1_1_1_1_1
              LONG %%2_2_2_0_0_0_0_0_0_2_2_2_1_1_1_1
              LONG %%0_2_2_2_0_0_0_0_0_0_2_2_2_1_1_1
              LONG %%0_0_2_2_2_0_0_0_0_0_1_2_2_2_1_1
              LONG %%0_0_0_2_2_2_0_0_0_0_1_1_2_2_2_1
              LONG %%0_0_0_0_2_2_2_0_0_0_1_1_1_2_2_2
              LONG %%0_0_0_0_0_2_2_2_0_0_1_1_1_1_2_2

' Extracted from file "PROFI_1PX.BMP" at tile=(15, 6), size=(16, 16), palette index=(111)
profi_1px_tx15_ty6_bitmap    LONG
              LONG %%2_2_0_0_0_0_0_0_2_2_2_0_0_0_0_0
              LONG %%2_2_2_0_0_0_0_0_0_2_2_2_0_0_0_0
              LONG %%0_2_2_2_0_0_0_0_0_0_2_2_2_0_0_0
              LONG %%0_0_2_2_2_0_0_0_1_1_1_2_2_2_1_1
              LONG %%0_0_0_2_2_2_1_1_1_1_1_1_2_2_2_1
              LONG %%0_0_0_0_2_2_2_1_1_1_1_1_1_2_2_2
              LONG %%0_0_0_0_1_2_2_2_1_1_1_1_1_1_2_2
              LONG %%0_0_0_0_1_1_2_2_2_1_1_1_1_1_1_2
              LONG %%2_0_0_1_1_1_1_2_2_2_1_1_1_1_1_1
              LONG %%2_2_0_1_1_1_1_1_2_2_2_1_1_1_1_1
              LONG %%2_2_2_1_1_1_1_1_1_2_2_2_1_1_1_1
              LONG %%0_2_2_2_1_1_1_1_1_1_2_2_2_1_1_1
              LONG %%0_0_2_2_2_1_1_1_1_1_1_2_2_2_1_1
              LONG %%0_0_0_2_2_2_1_1_1_1_1_1_2_2_2_0
              LONG %%0_0_0_1_2_2_2_1_1_1_1_1_1_2_2_2
              LONG %%0_0_0_1_1_2_2_2_1_1_1_1_1_0_2_2

{
'112 palettes extracted from file "PROFI_1PX.BMP" using palette color map 0
palette_map    LONG
PROFI_1PX_palette_map    LONG
              LONG $07_06_05_02 ' palette index 0
              LONG $07_05_04_02 ' palette index 1
              LONG $07_05_04_02 ' palette index 2
              LONG $07_05_04_02 ' palette index 3
              LONG $07_06_05_02 ' palette index 4
              LONG $07_06_05_02 ' palette index 5
              LONG $07_04_05_02 ' palette index 6
              LONG $07_04_05_02 ' palette index 7
              LONG $07_04_05_02 ' palette index 8
              LONG $07_4A_4B_02 ' palette index 9
              LONG $4A_4C_4B_02 ' palette index 10
              LONG $4A_4C_4B_02 ' palette index 11
              LONG $07_4A_4B_02 ' palette index 12
              LONG $07_06_4B_02 ' palette index 13
              LONG $07_4B_4C_02 ' palette index 14
              LONG $4A_4C_4B_02 ' palette index 15
              LONG $07_06_05_02 ' palette index 16
              LONG $07_04_05_02 ' palette index 17
              LONG $07_04_05_02 ' palette index 18
              LONG $07_04_05_02 ' palette index 19
              LONG $07_06_05_02 ' palette index 20
              LONG $07_04_05_02 ' palette index 21
              LONG $07_04_05_02 ' palette index 22
              LONG $07_04_05_02 ' palette index 23
              LONG $07_04_05_02 ' palette index 24
              LONG $4A_4B_4C_02 ' palette index 25
              LONG $4C_4B_4A_02 ' palette index 26
              LONG $4C_4B_4A_02 ' palette index 27
              LONG $4A_4B_4C_02 ' palette index 28
              LONG $07_4B_4C_02 ' palette index 29
              LONG $07_4B_4C_02 ' palette index 30
              LONG $07_4B_4C_02 ' palette index 31
              LONG $07_06_05_02 ' palette index 32
              LONG $07_04_05_02 ' palette index 33
              LONG $07_04_05_02 ' palette index 34
              LONG $07_06_04_02 ' palette index 35
              LONG $07_06_04_02 ' palette index 36
              LONG $07_04_05_02 ' palette index 37
              LONG $07_04_05_02 ' palette index 38
              LONG $05_04_4A_02 ' palette index 39
              LONG $05_04_4A_02 ' palette index 40
              LONG $4A_4C_4B_02 ' palette index 41
              LONG $4A_4B_4C_02 ' palette index 42
              LONG $4A_4B_4C_02 ' palette index 43
              LONG $4A_4C_4B_02 ' palette index 44
              LONG $07_4B_4C_02 ' palette index 45
              LONG $07_4C_4B_02 ' palette index 46
              LONG $07_4B_4C_02 ' palette index 47
              LONG $07_06_05_02 ' palette index 48
              LONG $07_06_04_02 ' palette index 49
              LONG $07_04_05_02 ' palette index 50
              LONG $07_04_05_02 ' palette index 51
              LONG $07_06_04_02 ' palette index 52
              LONG $05_04_4A_02 ' palette index 53
              LONG $05_04_4A_02 ' palette index 54
              LONG $07_4B_4C_02 ' palette index 55
              LONG $4C_4B_4A_02 ' palette index 56
              LONG $4A_4B_7C_02 ' palette index 57
              LONG $4A_7C_4B_02 ' palette index 58
              LONG $4A_7C_4B_02 ' palette index 59
              LONG $4A_4B_7C_02 ' palette index 60
              LONG $07_4B_4C_02 ' palette index 61
              LONG $4A_4C_4B_02 ' palette index 62
              LONG $07_4C_4B_02 ' palette index 63
              LONG $07_06_05_02 ' palette index 64
              LONG $07_04_05_02 ' palette index 65
              LONG $07_05_04_02 ' palette index 66
              LONG $07_05_04_02 ' palette index 67
              LONG $07_04_05_02 ' palette index 68
              LONG $07_06_05_02 ' palette index 69
              LONG $07_4B_4C_02 ' palette index 70
              LONG $07_4B_4A_02 ' palette index 71
              LONG $07_4B_4C_02 ' palette index 72
              LONG $4C_4B_4A_02 ' palette index 73
              LONG $4C_4B_4A_02 ' palette index 74
              LONG $07_4C_4B_02 ' palette index 75
              LONG $07_4C_4B_02 ' palette index 76
              LONG $07_4B_4C_02 ' palette index 77
              LONG $07_4B_4A_02 ' palette index 78
              LONG $07_4B_4C_02 ' palette index 79
              LONG $07_4B_4C_02 ' palette index 80
              LONG $07_4B_4C_02 ' palette index 81
              LONG $07_4C_4B_02 ' palette index 82
              LONG $07_06_04_02 ' palette index 83
              LONG $4A_4C_4B_02 ' palette index 84
              LONG $07_4C_4B_02 ' palette index 85
              LONG $07_4B_4A_02 ' palette index 86
              LONG $07_4B_4C_02 ' palette index 87
              LONG $07_06_EB_02 ' palette index 88
              LONG $07_06_EB_02 ' palette index 89
              LONG $07_06_EB_02 ' palette index 90
              LONG $07_06_EB_02 ' palette index 91
              LONG $07_06_7C_02 ' palette index 92
              LONG $07_06_7C_02 ' palette index 93
              LONG $07_4C_7C_02 ' palette index 94
              LONG $07_4C_7C_02 ' palette index 95
              LONG $07_06_EB_02 ' palette index 96
              LONG $07_06_EB_02 ' palette index 97
              LONG $07_06_7C_02 ' palette index 98
              LONG $07_06_7C_02 ' palette index 99
              LONG $07_06_7C_02 ' palette index 100
              LONG $07_06_4B_02 ' palette index 101
              LONG $07_06_4B_02 ' palette index 102
              LONG $07_06_EB_02 ' palette index 103
              LONG $07_06_EB_02 ' palette index 104
              LONG $07_06_4B_02 ' palette index 105
              LONG $07_06_4B_02 ' palette index 106
              LONG $07_06_4B_02 ' palette index 107
              LONG $07_7C_9C_02 ' palette index 108
              LONG $07_7C_9C_02 ' palette index 109
              LONG $07_4B_4C_02 ' palette index 110
              LONG $07_4B_4C_02 ' palette index 111    }
              
  
' 112 palettes extracted from file "profi_1px.bmp" using palette color map 1
palette_map    LONG
profi_1px_palette_map    LONG
              LONG $07_06_05_02 ' palette index 0
              LONG $07_05_04_02 ' palette index 1
              LONG $07_05_04_02 ' palette index 2
              LONG $07_05_04_02 ' palette index 3
              LONG $07_06_05_02 ' palette index 4
              LONG $07_06_05_02 ' palette index 5
              LONG $07_04_05_02 ' palette index 6
              LONG $07_04_05_02 ' palette index 7
              LONG $07_04_05_02 ' palette index 8
              LONG $07_7A_5A_02 ' palette index 9
              LONG $7A_5B_5A_02 ' palette index 10
              LONG $7A_5B_5A_02 ' palette index 11
              LONG $07_7A_5A_02 ' palette index 12
              LONG $07_06_5A_02 ' palette index 13
              LONG $07_5A_5B_02 ' palette index 14
              LONG $7A_5B_5A_02 ' palette index 15
              LONG $07_06_05_02 ' palette index 16
              LONG $07_04_05_02 ' palette index 17
              LONG $07_04_05_02 ' palette index 18
              LONG $07_04_05_02 ' palette index 19
              LONG $07_06_05_02 ' palette index 20
              LONG $07_04_05_02 ' palette index 21
              LONG $07_04_05_02 ' palette index 22
              LONG $07_04_05_02 ' palette index 23
              LONG $07_04_05_02 ' palette index 24
              LONG $7A_5A_5B_02 ' palette index 25
              LONG $5B_5A_7A_02 ' palette index 26
              LONG $5B_5A_7A_02 ' palette index 27
              LONG $7A_5A_5B_02 ' palette index 28
              LONG $07_5A_5B_02 ' palette index 29
              LONG $07_5A_5B_02 ' palette index 30
              LONG $07_5A_5B_02 ' palette index 31
              LONG $07_06_05_02 ' palette index 32
              LONG $07_04_05_02 ' palette index 33
              LONG $07_04_05_02 ' palette index 34
              LONG $07_06_04_02 ' palette index 35
              LONG $07_06_04_02 ' palette index 36
              LONG $07_04_05_02 ' palette index 37
              LONG $07_04_05_02 ' palette index 38
              LONG $05_04_7A_02 ' palette index 39
              LONG $05_04_7A_02 ' palette index 40
              LONG $7A_5B_5A_02 ' palette index 41
              LONG $7A_5A_5B_02 ' palette index 42
              LONG $7A_5A_5B_02 ' palette index 43
              LONG $7A_5B_5A_02 ' palette index 44
              LONG $07_5A_5B_02 ' palette index 45
              LONG $07_5B_5A_02 ' palette index 46
              LONG $07_5A_5B_02 ' palette index 47
              LONG $07_06_05_02 ' palette index 48
              LONG $07_06_04_02 ' palette index 49
              LONG $07_04_05_02 ' palette index 50
              LONG $07_04_05_02 ' palette index 51
              LONG $07_06_04_02 ' palette index 52
              LONG $05_04_7A_02 ' palette index 53
              LONG $05_04_7A_02 ' palette index 54
              LONG $07_5A_5B_02 ' palette index 55
              LONG $5B_5A_7A_02 ' palette index 56
              LONG $7A_5A_6C_02 ' palette index 57
              LONG $7A_6C_5A_02 ' palette index 58
              LONG $7A_6C_5A_02 ' palette index 59
              LONG $7A_5A_6C_02 ' palette index 60
              LONG $07_5A_5B_02 ' palette index 61
              LONG $7A_5B_5A_02 ' palette index 62
              LONG $07_5B_5A_02 ' palette index 63
              LONG $07_06_05_02 ' palette index 64
              LONG $07_04_05_02 ' palette index 65
              LONG $07_05_04_02 ' palette index 66
              LONG $07_05_04_02 ' palette index 67
              LONG $07_04_05_02 ' palette index 68
              LONG $07_06_05_02 ' palette index 69
              LONG $07_5A_5B_02 ' palette index 70
              LONG $07_5A_7A_02 ' palette index 71
              LONG $07_5A_5B_02 ' palette index 72
              LONG $5B_5A_7A_02 ' palette index 73
              LONG $5B_5A_7A_02 ' palette index 74
              LONG $07_5B_5A_02 ' palette index 75
              LONG $07_5B_5A_02 ' palette index 76
              LONG $07_5A_5B_02 ' palette index 77
              LONG $07_5A_7A_02 ' palette index 78
              LONG $07_5A_5B_02 ' palette index 79
              LONG $07_5A_5B_02 ' palette index 80
              LONG $07_5A_5B_02 ' palette index 81
              LONG $07_5B_5A_02 ' palette index 82
              LONG $07_06_04_02 ' palette index 83
              LONG $7A_5B_5A_02 ' palette index 84
              LONG $07_5B_5A_02 ' palette index 85
              LONG $07_5A_7A_02 ' palette index 86
              LONG $07_5A_5B_02 ' palette index 87
              LONG $07_06_FA_02 ' palette index 88
              LONG $07_06_FA_02 ' palette index 89
              LONG $07_06_FA_02 ' palette index 90
              LONG $07_06_FA_02 ' palette index 91
              LONG $07_06_6C_02 ' palette index 92
              LONG $07_06_6C_02 ' palette index 93
              LONG $07_5B_6C_02 ' palette index 94
              LONG $07_5B_6C_02 ' palette index 95
              LONG $07_06_FA_02 ' palette index 96
              LONG $07_06_FA_02 ' palette index 97
              LONG $07_06_6C_02 ' palette index 98
              LONG $07_06_6C_02 ' palette index 99
              LONG $07_06_6C_02 ' palette index 100
              LONG $07_06_5A_02 ' palette index 101
              LONG $07_06_5A_02 ' palette index 102
              LONG $07_06_FA_02 ' palette index 103
              LONG $07_06_FA_02 ' palette index 104
              LONG $07_06_5A_02 ' palette index 105
              LONG $07_06_5A_02 ' palette index 106
              LONG $07_06_5A_02 ' palette index 107
              LONG $07_6C_AB_02 ' palette index 108
              LONG $07_6C_AB_02 ' palette index 109
              LONG $07_5A_5B_02 ' palette index 110
              LONG $07_5A_5B_02 ' palette index 111     